﻿using MicroCloud;
using MicroCloud.AspNetCore;
using MicroCloud.AspNetCore.Mvc.Filters;
using MicroCloud.Authorization.Functions;
using MicroCloud.Authorization.Modules;
using MicroCloud.Data;
using MicroCloud.Extensions;
using MicroCloud.Filter;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using NPOI.SS.Formula.Functions;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Linq.Expressions;
using System.Threading.Tasks;
using Entity = Vinno.WMS.Pack.Core.Entities.MaterialThreeLevel;
using IContractService = Vinno.WMS.Pack.Core.IWmsService;
using InputDto = Vinno.WMS.Pack.Core.Dtos.MaterialThreeLevelInputDto;
using OutputDto = Vinno.WMS.Pack.Core.Dtos.MaterialThreeLevelOutputDto;

namespace Vinno.WMS.Apis.Areas.Admin.Controllers
{
    [Description("物料分类三级")]
    [Module(OrderNo = 6, Position = "Wms", PositionName = "仓储模块")]
    public class MaterialThreeLevelController : AdminControllerBase
    {
        /// <summary>
        /// 获取 服务接口
        /// </summary>
        protected IContractService ContractService => ServiceProvider.GetService<IContractService>();

        /// <summary>
        /// 读取
        /// </summary>
        [HttpPost]
        [Description("读取")]
        [Module]
        public PageData<OutputDto> Read(PageRequest request)
        {
            Check.NotNull(request, nameof(request));
            IFunction function = this.GetExecuteFunction();
            Expression<Func<Entity, bool>> predicate = FilterService.GetExpression<Entity>(request.FilterGroup);
            var pageData = ContractService.MaterialThreeLevels.ToPage(predicate,
             request.PageCondition,
             m => new
             {
                 D = m,
                 ParentName = $"{m.TwoLevel.OneLevel.Name}-{m.TwoLevel.Name}"
             });

            var page = pageData.ToPageResult(data => data.Select(m =>
             {
                 var outDto = m.D.MapTo<OutputDto>();
                 outDto.ParentName = m.ParentName;
                 return outDto;
             }).ToArray());

            return page.ToPageData();
        }

        /// <summary>
        /// 新增
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("新增")]
        [Module]
        public async Task<AjaxResult> Create(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.CreateMaterialThreeLevels(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”创建成功");
        }

        /// <summary>
        /// 更新
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("更新")]
        [Module]
        public async Task<AjaxResult> Update(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.UpdateMaterialThreeLevels(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”更新成功");
        }

        /// <summary>
        /// 删除
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("删除")]
        [Module]
        public async Task<AjaxResult> Delete(Guid[] ids)
        {
            Check.NotNull(ids, nameof(ids));
            var result = await ContractService.DeleteMaterialTwoLevels(ids);
            return result.ToAjaxResult();
        }

    }
}