﻿using MicroCloud;
using MicroCloud.AspNetCore.Mvc.Filters;
using MicroCloud.Authorization.Functions;
using MicroCloud.Authorization.Modules;
using MicroCloud.Data;
using MicroCloud.Extensions;
using MicroCloud.Filter;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Microsoft.Extensions.DependencyInjection;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Linq.Expressions;
using System.Threading.Tasks;
using Vinno.WMS.Pack.Core.Dtos;
using Entity = Vinno.WMS.Pack.Core.Entities.MaterialOneLevel;
using IContractService = Vinno.WMS.Pack.Core.IWmsService;
using InputDto = Vinno.WMS.Pack.Core.Dtos.MaterialOneLevelInputDto;
using OutputDto = Vinno.WMS.Pack.Core.Dtos.MaterialOneLevelOutputDto;

namespace Vinno.WMS.Apis.Areas.Admin.Controllers
{
    [Description("物料分类一级")]
    [Module(OrderNo = 4, Position = "Wms", PositionName = "仓储模块")]
    public class MaterialOneLevelController : AdminControllerBase
    {
        /// <summary>
        /// 获取 服务接口
        /// </summary>
        protected IContractService ContractService => ServiceProvider.GetService<IContractService>();

        /// <summary>
        /// 读取
        /// </summary>
        [HttpPost]
        [Description("读取")]
        [Module]
        public PageData<OutputDto> Read(PageRequest request)
        {
            Check.NotNull(request, nameof(request));
            IFunction function = this.GetExecuteFunction();

            Expression<Func<Entity, bool>> predicate = FilterService.GetExpression<Entity>(request.FilterGroup);
            var page = CacheService.ToPageCache<Entity, OutputDto>(ContractService.MaterialOneLevels, predicate, request.PageCondition,
               function);

            return page.ToPageData();
        }

        /// <summary>
        /// 新增
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("新增")]
        [Module]
        public async Task<AjaxResult> Create(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.CreateMaterialOneLevels(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”创建成功");
        }

        /// <summary>
        /// 更新
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("更新")]
        [Module]
        public async Task<AjaxResult> Update(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.UpdateMaterialOneLevels(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”更新成功");
        }

        /// <summary>
        /// 删除
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("删除")]
        [Module]
        public async Task<AjaxResult> Delete(Guid[] ids)
        {
            Check.NotNull(ids, nameof(ids));
            var result = await ContractService.DeleteMaterialOneLevels(ids);
            return result.ToAjaxResult();
        }

        [HttpPost]
        public object[] ReadNode()
        {
            var nodes = ContractService.MaterialOneLevels.Select(a => new
            {
                Id = a.Id,
                Name = a.Name,
            }).OrderBy(a => a.Name).ToArray();
            return nodes;
        }

        [HttpPost]
        [AllowAnonymous]
        public AjaxResult ReadNodes()
        {
            var nodes = ContractService.MaterialOneLevels.Select(a => new
            {
                a.Id,
                a.Name
            }).ToList();
            return AjaxResult.Success(nodes);
        }

        [HttpPost]
        [AllowAnonymous]
        public AjaxResult ReadTreeNode()
        {
            List<MaterialTreeNode> treeNodes = new();
            var entities = ContractService.MaterialOneLevels.Include(a => a.TwoLevels).ThenInclude(a => a.ThreeLevels).ToList();
            if (entities == null || entities?.Count == 0) return AjaxResult.Success();

            entities.ForEach(one =>
            {
                treeNodes.Add(new MaterialTreeNode
                {
                    Id = one.Id,
                    Name = one.Name,
                    Description = one.Description,
                    Childrens = one.TwoLevels.Select(a => new MaterialTreeNode
                    {
                        Id = a.Id,
                        Name = a.Name,
                        FrnName = a.FrnName,
                        Description = a.Description,
                        Childrens = a.ThreeLevels.Select(b => new MaterialTreeNode
                        {
                            Id = b.Id,
                            Name = b.Name,
                            Description = b.Description,
                        }).ToList()
                    }).ToList()
                });
            });
            var data = treeNodes.ToArray();
            return AjaxResult.Success(data);
        }

    }
}