﻿using Entity = Vinno.WMS.Pack.Core.Entities.WareHouse;
using IContractService = Vinno.WMS.Pack.Core.IWmsService;
using InputDto = Vinno.WMS.Pack.Core.Dtos.WareHouseInputDto;
using OutputDto = Vinno.WMS.Pack.Core.Dtos.WareHouseOutputDto;

namespace Vinno.WMS.Apis.Areas.Admin.Controllers
{
    [Description("仓库信息")]
    [Module(OrderNo = 1, Position = "Wms", PositionName = "仓储模块")]
    public class WareHouseController : AdminControllerBase
    {
        /// <summary>
        /// 获取 服务接口
        /// </summary>
        protected IContractService ContractService => ServiceProvider.GetService<IContractService>();

        /// <summary>
        /// 读取
        /// </summary>
        [HttpPost]
        [Description("读取")]
        [Module]
        public PageData<OutputDto> Read(PageRequest request)
        {
            Check.NotNull(request, nameof(request));
            IFunction function = this.GetExecuteFunction();

            Expression<Func<Entity, bool>> predicate = FilterService.GetExpression<Entity>(request.FilterGroup);
            var page = CacheService.ToPageCache<Entity, OutputDto>(ContractService.WareHouses, predicate, request.PageCondition,
               function);

            return page.ToPageData();
        }

        /// <summary>
        /// 新增
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("新增")]
        [Module]
        public async Task<AjaxResult> Create(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.CreateWareHouses(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”创建成功");
        }

        /// <summary>
        /// 更新
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("更新")]
        [Module]
        public async Task<AjaxResult> Update(InputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<OutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                var result = await ContractService.UpdateWareHouses(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<OutputDto>());
            }
            return AjaxResult.Success(outputDtos, $"{nameof(Entity)}“{ids.ExpandAndToString()}”更新成功");
        }

        /// <summary>
        /// 删除
        /// </summary>
        [HttpPost]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("删除")]
        [Module]
        public async Task<AjaxResult> Delete(Guid[] ids)
        {
            Check.NotNull(ids, nameof(ids));
            var result = await ContractService.DeleteWareHouses(ids);
            return result.ToAjaxResult();
        }

        [HttpPost]
        public object[] ReadNode()
        {
            var nodes = ContractService.WareHouses.Select(a => new
            {
                a.Id,
                a.Name,
            }).OrderBy(a => a.Name).ToArray();
            return nodes;
        }

        /// <summary>
        /// 读取树节点
        /// </summary>
        /// <returns>组织机构树页列表</returns>
        [HttpPost]
        [AllowAnonymous]
        [Description("读取树")]
        public AjaxResult GetTreeNodes()
        {
            //IFunction function = this.GetExecuteFunction();

            var datas = ContractService.WareHouses.Select(a => new
            {
                a.Id,
                a.Name,
                Level = 1,
                Children = a.WareHouseAreas.Select(b => new
                {
                    b.Id,
                    Name = b.AreaName,
                    Level = 2,
                    Children = b.WareHouseAreaPoses.Select(c => new
                    {
                        c.Id,
                        Name = c.AreaPosName,
                        Level = 3
                    })
                })
            }).ToList();
            return AjaxResult.Success(datas);
            //var nodeList = CacheService.ToCacheList(ContractService.WareHouses, m => m.MapTo<MaterialCategory, MaterialCategoryNodeDto>(), function);
            //var treeNodes = nodeList.ToTreeNodes();
            //return AjaxResult.Success(treeNodes.ToArray());
        }

    }
}