﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private MaterialOneLevelStore MaterialOneLevelStore => ServiceProvider.GetService<MaterialOneLevelStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<MaterialOneLevel> MaterialOneLevels => MaterialOneLevelStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<MaterialOneLevelOutputDto>> FindMaterialOneLevelById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = MaterialOneLevels.Where(o => o.Id.Equals(id)).ToOutput<MaterialOneLevel, MaterialOneLevelOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<MaterialOneLevelOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<MaterialOneLevelOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateMaterialOneLevels(params MaterialOneLevelInputDto[] dtos)
        {
            return await MaterialOneLevelStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateMaterialOneLevels(params MaterialOneLevelInputDto[] dtos)
        {
            return await MaterialOneLevelStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteMaterialOneLevels(params Guid[] ids)
        {
            return await MaterialOneLevelStore.DeleteAsync(ids);
        }

    }
}