﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private MaterialThreeLevelStore MaterialThreeLevelStore => ServiceProvider.GetService<MaterialThreeLevelStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<MaterialThreeLevel> MaterialThreeLevels => MaterialThreeLevelStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<MaterialThreeLevelOutputDto>> FindMaterialThreeLevelById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = MaterialThreeLevels.Where(o => o.Id.Equals(id)).ToOutput<MaterialThreeLevel, MaterialThreeLevelOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<MaterialThreeLevelOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<MaterialThreeLevelOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateMaterialThreeLevels(params MaterialThreeLevelInputDto[] dtos)
        {
            return await MaterialThreeLevelStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateMaterialThreeLevels(params MaterialThreeLevelInputDto[] dtos)
        {
            return await MaterialThreeLevelStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteMaterialThreeLevels(params Guid[] ids)
        {
            return await MaterialThreeLevelStore.DeleteAsync(ids);
        }

    }
}