﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private MaterialTwoLevelStore MaterialTwoLevelStore => ServiceProvider.GetService<MaterialTwoLevelStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<MaterialTwoLevel> MaterialTwoLevels => MaterialTwoLevelStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<MaterialTwoLevelOutputDto>> FindMaterialTwoLevelById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = MaterialTwoLevels.Where(o => o.Id.Equals(id)).ToOutput<MaterialTwoLevel, MaterialTwoLevelOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<MaterialTwoLevelOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<MaterialTwoLevelOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateMaterialTwoLevels(params MaterialTwoLevelInputDto[] dtos)
        {
            return await MaterialTwoLevelStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateMaterialTwoLevels(params MaterialTwoLevelInputDto[] dtos)
        {
            return await MaterialTwoLevelStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteMaterialTwoLevels(params Guid[] ids)
        {
            return await MaterialTwoLevelStore.DeleteAsync(ids);
        }

    }
}