﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private WareHouseStore WareHouseStore => ServiceProvider.GetService<WareHouseStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<WareHouse> WareHouses => WareHouseStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<WareHouseOutputDto>> FindWareHouseById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = WareHouses.Where(o => o.Id.Equals(id)).ToOutput<WareHouse, WareHouseOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<WareHouseOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<WareHouseOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateWareHouses(params WareHouseInputDto[] dtos)
        {
            return await WareHouseStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateWareHouses(params WareHouseInputDto[] dtos)
        {
            return await WareHouseStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteWareHouses(params Guid[] ids)
        {
            return await WareHouseStore.DeleteAsync(ids);
        }

    }
}