﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private WareHouseAreaStore WareHouseAreaStore => ServiceProvider.GetService<WareHouseAreaStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<WareHouseArea> WareHouseAreas => WareHouseAreaStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<WareHouseAreaOutputDto>> FindWareHouseAreaById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = WareHouseAreas.Where(o => o.Id.Equals(id)).ToOutput<WareHouseArea, WareHouseAreaOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<WareHouseAreaOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<WareHouseAreaOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateWareHouseAreas(params WareHouseAreaInputDto[] dtos)
        {
            return await WareHouseAreaStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateWareHouseAreas(params WareHouseAreaInputDto[] dtos)
        {
            return await WareHouseAreaStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteWareHouseAreas(params Guid[] ids)
        {
            return await WareHouseAreaStore.DeleteAsync(ids);
        }

    }
}