﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private WareHouseAreaPosStore WareHouseAreaPosStore => ServiceProvider.GetService<WareHouseAreaPosStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<WareHouseAreaPos> WareHouseAreaPoss => WareHouseAreaPosStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<WareHouseAreaPosOutputDto>> FindWareHouseAreaPosById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = WareHouseAreaPoss.Where(o => o.Id.Equals(id)).ToOutput<WareHouseAreaPos, WareHouseAreaPosOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<WareHouseAreaPosOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<WareHouseAreaPosOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateWareHouseAreaPoss(params WareHouseAreaPosInputDto[] dtos)
        {
            return await WareHouseAreaPosStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateWareHouseAreaPoss(params WareHouseAreaPosInputDto[] dtos)
        {
            return await WareHouseAreaPosStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteWareHouseAreaPoss(params Guid[] ids)
        {
            return await WareHouseAreaPosStore.DeleteAsync(ids);
        }

    }
}