﻿namespace Vinno.WMS.Pack.Core
{
    public partial class WmsService
    {
        /// <summary>
        /// 获取 实体仓储对象
        /// </summary>
        private MaterialStore MaterialStore => ServiceProvider.GetService<MaterialStore>();

        /// <summary>
        /// 获取 实体查询数据集
        /// </summary>
        public IQueryable<Material> Materials => MaterialStore.Entities;

        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="id">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult<MaterialOutputDto>> FindMaterialById(Guid id)
        {
            Check.NotEmpty(id, nameof(id));

            var outputDto = Materials.Where(o => o.Id.Equals(id)).ToOutput<Material, MaterialOutputDto>().FirstOrDefault();
            if (outputDto != null)
            {
                return await Task.FromResult(new OperationResult<MaterialOutputDto>(OperationResultType.Success, "OK", outputDto));
            }

            return await Task.FromResult(new OperationResult<MaterialOutputDto>(OperationResultType.NotFound, "Not Found", outputDto));
        }

        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> CreateMaterials(params MaterialInputDto[] dtos)
        {
            return await MaterialStore.InsertByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> UpdateMaterials(params MaterialInputDto[] dtos)
        {
            return await MaterialStore.UpdateByDtoAsync(dtos);
        }

        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="ids">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public async Task<OperationResult> DeleteMaterials(params Guid[] ids)
        {
            return await MaterialStore.DeleteAsync(ids);
        }

    }
}