import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { EntityUserOutputDto, EntityUserInputDto } from './model';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';

/** 管理-用户数据权限枚举 */
enum Api {
  /** 读取用户数据权限列表信息 */
  Read = '/api/admin/userEntity/read',

  /** 新增用户数据权限信息 */
  Create = '/api/admin/userEntity/create',
  /** 更新用户数据权限信息 */
  Update = '/api/admin/userEntity/update',
  /** 删除用户数据权限信息 */
  Delete = '/api/admin/userEntity/delete',
}

//#region 读取用户数据权限列表信息
/**
 * 读取用户数据权限列表信息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readUserEntities(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<EntityUserOutputDto>>(
    {
      url: Api.Read,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 新增用户数据权限信息
/**
 * 新增用户数据权限信息
 * @param dtos 用户数据权限信息
 * @param mode 错误消息模型
 */
export function createUserEntities(dtos: EntityUserInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Create,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 更新用户数据权限信息
/**
 * 更新用户数据权限信息
 * @param dtos 用户数据权限信息
 * @param mode 错误消息模型
 */
export function updateUserEntities(dtos: EntityUserInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Update,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 删除用户数据权限信息
/**
 * 删除用户数据权限信息
 * @param ids 用户数据权限编号集合
 * @param mode 错误消息模型
 */
export function deleteUserEntities(ids: (string | bigint)[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Delete,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
