import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { UserOutputDtoSimple } from '/@/api/identity/admin/user/model';
import { FunctionOutputDtoSimple } from '/@/api/authorization/admin/function/model';
import { PageRequest, PageData } from '/@/utils/common/types';

/** 管理-用户功能枚举 */
export enum Api {
  /** 读取用户 */
  ReadUsers = '/api/admin/userFunction/readUsers',
  /** 读取用户功能 */
  ReadFunctions = '/api/admin/userFunction/readFunctions',
}

//#region 读取用户信息
/**
 * 读取用户信息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readUsers(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<UserOutputDtoSimple>>(
    {
      url: Api.ReadUsers,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 读取用户功能信息
/**
 * 读取用户功能信息
 * @param userId 用户ID
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readUserFunctions(
  userId: string | bigint,
  request: PageRequest,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<PageData<FunctionOutputDtoSimple>>(
    {
      url: `${Api.ReadFunctions}?userId=${userId}`,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
