import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { PageRequest, PageData } from '/@/utils/common/types';
import { AjaxResult } from '../../../model';
import { QueryMessageInputDto, QueryMessageOutputDto } from './model';

/** 管理-查询消息URL枚举 */
enum Api {
  /** 读取查询消息 */
  Read = '/api/admin/queryMessage/read',
  /** 新增查询消息 */
  Create = '/api/admin/queryMessage/create',
  /** 更新查询消息 */
  Update = '/api/admin/queryMessage/update',
  /** 删除查询消息 */
  Delete = '/api/admin/queryMessage/delete',
  /** 发送查询消息 */
  Send = '/api/admin/queryMessage/send',
}

/**
 * 读取查询消息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readQueryMessages(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<QueryMessageOutputDto>>(
    {
      url: Api.Read,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 新增查询消息
 * @param dtos 消息DTO
 * @param mode 错误消息模型
 */
export function createQueryMessages(
  dtos: QueryMessageInputDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Create,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 更新查询消息
 * @param dtos 消息DTO
 * @param mode 错误消息模型
 */
export function updateQueryMessages(
  dtos: QueryMessageInputDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Update,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 删除查询消息
 * @param ids 消息编号
 * @param mode 错误消息模型
 */
export function deleteQueryMessages(ids: (string | bigint)[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Delete,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 发送查询消息
 * @param ids 消息编号
 * @param mode 错误消息模型
 */
export function sendQueryMessages(ids: (string | bigint)[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Send,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
