import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { PageRequest, PageData } from '/@/utils/common/types';
import { AjaxResult } from '../model';
import { MessageDtoSimple, MessageDto, MessageRequestDto, MessageReadDto } from './model';

/** 消息模块URL枚举 */
enum Api {
  /** 获取消息 */
  GetMessages = '/api/message/getMessages',
  /** 获取未读消息 */
  GetUnreadMessages = '/api/message/getUnreadMessages',
  /** 获取消息详情 */
  GetMessageDetails = '/api/message/getMessageDetails',
  /** 阅读消息 */
  ReadMessages = '/api/message/readMessages',
  /** 删除消息 */
  DeleteMessages = '/api/message/deleteMessages',
}

/**
 * 获取消息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function getMessages(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<MessageDtoSimple>>(
    {
      url: Api.GetMessages,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 获取未读消息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function getUnreadMessages(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<MessageDtoSimple>>(
    {
      url: Api.GetUnreadMessages,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 获取消息详情
 * @param dto 消息请求DTO
 * @param mode 错误消息模型
 */
export function getMessageDetails(dto: MessageRequestDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult<MessageDto[]>>(
    {
      url: Api.GetMessageDetails,
      params: dto,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 阅读消息
 * @param dto 消息请求DTO
 * @param mode 错误消息模型
 */
export function readMessages(dto: MessageReadDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ReadMessages,
      params: dto,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 删除消息
 * @param messageIds 消息编号
 * @param mode 错误消息模型
 */
export function deleteMessages(
  messageIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.DeleteMessages,
      params: messageIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
