import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';
import {
  PrintInputDto,
  PrintOutputDto,
  PrintTemplateInputDtoSimple,
  PrintTemplateInputDto,
  PrintTemplateFileInputDto,
  PrintTemplateOutputDto,
  PrintUserDto,
  PrintTemplateUserDto,
  PrintTemplateUserOutputDtoSimple,
  PrintOrganizationDto,
  PrintTemplateOrganizationDto,
  PrintTemplateOrganizationOutputDtoSimple,
  PrintLogOutputDto,
  PrintTemplateNode,
  PrintTemplateSetUserDto,
  UserSetPrintTemplateDto,
  OrganizationSetPrintTemplateDto,
  PrintTemplateSetOrganizationDto,
} from './model';
import { UserNode } from '/@/api/identity/admin/user/model';
import { OrganizationNodeSimple } from '/@/api/identity/admin/organization/model';
import { ReportTypeEnum } from '/@/enums/reportTypeEnum';

/** 报表打印模块URL枚举 */
enum Api {
  /** 获取报表文件 */
  GetReportFile = '/api/admin/print/getReportFile',
  /** 获取数据源连接集合 */
  GetDsConnections = '/api/admin/print/getDsConnections',
  /** 获取数据源配置XML */
  GetDsConfigXml = '/api/admin/print/getDsConfigXml',
  /** 获取数据源配置XSD */
  GetDsConfigXsd = '/api/admin/print/getDsConfigXsd',
  /** 读取打印 */
  ReadPrints = '/api/admin/print/readPrints',
  /** 创建打印 */
  CreatePrints = '/api/admin/print/createPrints',
  /** 更新打印 */
  UpdatePrints = '/api/admin/print/updatePrints',
  /** 删除打印 */
  DeletePrints = '/api/admin/print/deletePrints',
  /** 读取模板 */
  ReadTemplates = '/api/admin/print/readTemplates',
  /** 创建模板 */
  CreateTemplates = '/api/admin/print/createTemplates',
  /** 更新模板 */
  UpdateTemplates = '/api/admin/print/updateTemplates',
  /** 更新模板信息 */
  UpdateTemplateInfos = '/api/admin/print/updateTemplateInfos',
  /** 更新模板文件 */
  UpdateTemplateFiles = '/api/admin/print/updateTemplateFiles',
  /** 删除模板 */
  DeleteTemplates = '/api/admin/print/deleteTemplates',
  /** 获取模板文件 */
  GetTemplateFile = '/api/admin/print/getTemplateFile',
  /** 读取打印[用户]树数据 */
  ReadPrintUserNodes = '/api/admin/print/readPrintUserNodes',
  /** 读取用户[打印]树数据 */
  ReadUserPrintNodes = '/api/admin/print/readUserPrintNodes',
  /** 设置用户的打印 */
  SetUserPrints = '/api/admin/print/setUserPrints',
  /** 设置打印的用户 */
  SetPrintUsers = '/api/admin/print/setPrintUsers',
  /** 读取打印用户 */
  ReadPrintUsers = '/api/admin/print/readPrintUsers',
  /** 创建打印用户 */
  CreatePrintUsers = '/api/admin/print/createPrintUsers',
  /** 取消打印用户默认设置 */
  CancelDefaultPrintUsers = '/api/admin/print/cancelDefaultPrintUsers',
  /** 设置打印用户默认设置 */
  SetDefaultPrintUsers = '/api/admin/print/setDefaultPrintUsers',
  /** 删除打印用户 */
  DeletePrintUsers = '/api/admin/print/deletePrintUsers',
  /** 清除打印用户 */
  ClearPrintUsers = '/api/admin/print/clearPrintUsers',
  /** 根据模板清除打印用户 */
  ClearPrintUsersByTemplate = '/api/admin/print/clearPrintUsersByTemplate',
  /** 根据打印清除打印用户 */
  ClearPrintUsersByPrint = '/api/admin/print/clearPrintUsersByPrint',
  /** 读取打印[组织]树数据 */
  ReadPrintOrganizationNodes = '/api/admin/print/readPrintOrganizationNodes',
  /** 读取组织[打印]树数据 */
  ReadOrganizationPrintNodes = '/api/admin/print/readOrganizationPrintNodes',
  /** 设置组织的打印 */
  SetOrganizationPrints = '/api/admin/print/setOrganizationPrints',
  /** 设置打印的组织 */
  SetPrintOrganizations = '/api/admin/print/setPrintOrganizations',
  /** 读取打印组织 */
  ReadPrintOrganizations = '/api/admin/print/readPrintOrganizations',
  /** 创建打印组织 */
  CreatePrintOrganizations = '/api/admin/print/createPrintOrganizations',
  /** 删除打印组织 */
  DeletePrintOrganizations = '/api/admin/print/deletePrintOrganizations',
  /** 清除打印组织 */
  ClearPrintOrganizations = '/api/admin/print/clearPrintOrganizations',
  /** 根据模板清除打印组织 */
  ClearPrintOrganizationsByTemplate = '/api/admin/print/clearPrintOrganizationsByTemplate',
  /** 根据打印清除打印组织 */
  ClearPrintOrganizationsByPrint = '/api/admin/print/clearPrintOrganizationsByPrint',
  /** 读取打印日志 */
  ReadPrintLogs = '/api/admin/print/readPrintLogs',
}

//#region 获取报表文件
/**
 * 获取报表文件
 * @param reportType 报表类型
 * @param mode 错误消息模型
 */
export function getReportFile(reportType: ReportTypeEnum, mode: ErrorMessageMode = 'message') {
  return httpClient.get(
    {
      url: Api.GetReportFile,
      params: { reportType: reportType },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 获取数据源连接集合
/**
 * 获取数据源连接集合
 * @param reportType 报表类型
 * @param mode 错误消息模型
 */
export function getDsConnections(reportType: ReportTypeEnum, mode: ErrorMessageMode = 'message') {
  return httpClient.get(
    {
      url: Api.GetDsConnections,
      params: { reportType: reportType },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 获取数据源配置XML
/**
 * 获取数据源配置XML
 * @param mode 错误消息模型
 */
export function getDsConfigXml(mode: ErrorMessageMode = 'message') {
  return httpClient.get(
    {
      url: Api.GetDsConfigXml,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 获取数据源配置XSD
/**
 * 获取数据源配置XSD
 * @param mode 错误消息模型
 */
export function getDsConfigXsd(mode: ErrorMessageMode = 'message') {
  return httpClient.get(
    {
      url: Api.GetDsConfigXsd,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 读取打印
/**
 * 读取打印
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readPrints(request: PageRequest, mode: ErrorMessageMode = 'message') {
  // console.log('readPrints', { request });
  return httpClient.post<PageData<PrintOutputDto>>(
    {
      url: Api.ReadPrints,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 创建打印
/**
 * 创建打印
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function createPrints(dtos: PrintInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.CreatePrints,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 更新打印
/**
 * 更新打印
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function updatePrints(dtos: PrintInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.UpdatePrints,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 删除打印
/**
 * 删除打印
 * @param printIds 打印编号
 * @param mode 错误消息模型
 */
export function deletePrints(printIds: (string | bigint)[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.DeletePrints,
      params: printIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 读取模板
/**
 * 读取模板
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readTemplates(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<PrintTemplateOutputDto>>(
    {
      url: Api.ReadTemplates,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 创建模板
/**
 * 创建模板
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function createTemplates(dtos: PrintTemplateInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.CreateTemplates,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 更新模板
/**
 * 更新模板
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function updateTemplates(dtos: PrintTemplateInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.UpdateTemplates,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 更新模板信息
/**
 * 更新模板信息
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function updateTemplateInfos(
  dtos: PrintTemplateInputDtoSimple[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.UpdateTemplateInfos,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 更新模板文件
/**
 * 更新模板文件
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function updateTemplateFiles(
  dtos: PrintTemplateFileInputDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.UpdateTemplateFiles,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 删除模板
/**
 * 删除模板
 * @param templateIds 模板编号
 * @param mode 错误消息模型
 */
export function deleteTemplates(
  templateIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.DeleteTemplates,
      params: templateIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 获取模板文件
/**
 * 获取模板文件
 * @param templateId 模板编号
 * @param mode 错误消息模型
 */
export function getTemplateFile(templateId: string | bigint, mode: ErrorMessageMode = 'message') {
  return httpClient.get<AjaxResult>(
    {
      url: Api.GetTemplateFile,
      params: { templateId: templateId },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 读取打印[用户]树数据
/**
 * 读取打印[用户]树数据
 * @param templateId 模板编号
 * @param mode 错误消息模型
 */
export function readPrintUserNodes(
  templateId: string | bigint,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.get<UserNode[]>(
    {
      url: Api.ReadPrintUserNodes,
      params: { templateId: templateId },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 读取用户[打印]树数据
/**
 * 读取用户[打印]树数据
 * @param userId 用户编号
 * @param mode 错误消息模型
 */
export function readUserPrintNodes(userId: string | bigint, mode: ErrorMessageMode = 'message') {
  return httpClient.get<PrintTemplateNode[]>(
    {
      url: Api.ReadUserPrintNodes,
      params: { userId: userId },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 设置用户的打印
/**
 * 设置用户的打印
 * @param dtos 用户打印模板
 * @param mode 错误消息模型
 */
export function setUserPrints(dtos: UserSetPrintTemplateDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.SetUserPrints,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 设置打印的用户
/**
 * 设置打印的用户
 * @param dtos 打印模板用户
 * @param mode 错误消息模型
 */
export function setPrintUsers(dtos: PrintTemplateSetUserDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.SetPrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 读取打印用户
/**
 * 读取打印用户
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readPrintUsers(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<PrintTemplateUserOutputDtoSimple>>(
    {
      url: Api.ReadPrintUsers,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 创建打印用户
/**
 * 创建打印用户
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function createPrintUsers(dtos: PrintTemplateUserDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.CreatePrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 取消打印用户默认设置
/**
 * 取消打印用户默认设置
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function cancelDefaultPrintUsers(dtos: PrintUserDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.CancelDefaultPrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 设置打印用户默认设置
/**
 * 设置打印用户默认设置
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function setDefaultPrintUsers(
  dtos: PrintTemplateUserDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.SetDefaultPrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 删除打印用户
/**
 * 删除打印用户
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function deletePrintUsers(dtos: PrintTemplateUserDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.DeletePrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 清除打印用户
/**
 * 清除打印用户
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function clearPrintUsers(dtos: PrintUserDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintUsers,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 根据模板清除打印用户
/**
 * 根据模板清除打印用户
 * @param templateIds 模板编号
 * @param mode 错误消息模型
 */
export function clearPrintUsersByTemplate(
  templateIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintUsersByTemplate,
      params: templateIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 根据打印清除打印用户
/**
 * 根据打印清除打印用户
 * @param printIds 打印编号
 * @param mode 错误消息模型
 */
export function clearPrintUsersByPrint(
  printIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintUsersByPrint,
      params: printIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 读取打印[组织]树数据
/**
 * 读取打印[组织]树数据
 * @param templateId 模板编号
 * @param mode 错误消息模型
 */
export function readPrintOrganizationNodes(
  templateId: string | bigint,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.get<OrganizationNodeSimple[]>(
    {
      url: Api.ReadPrintOrganizationNodes,
      params: { templateId: templateId },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 读取组织[打印]树数据
/**
 * 读取组织[打印]树数据
 * @param organizationId 组织机构编号
 * @param mode 错误消息模型
 */
export function readOrganizationPrintNodes(
  organizationId: string | bigint,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.get<PrintTemplateNode[]>(
    {
      url: Api.ReadOrganizationPrintNodes,
      params: { organizationId: organizationId },
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 设置组织的打印
/**
 * 设置组织的打印
 * @param dtos 组织机构打印模板
 * @param mode 错误消息模型
 */
export function setOrganizationPrints(
  dtos: OrganizationSetPrintTemplateDto,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.SetOrganizationPrints,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 设置打印的组织
/**
 * 设置打印的组织
 * @param dtos 打印模板组织机构
 * @param mode 错误消息模型
 */
export function setPrintOrganizations(
  dtos: PrintTemplateSetOrganizationDto,
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.SetPrintOrganizations,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 读取打印组织
/**
 * 读取打印组织
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readPrintOrganizations(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<PrintTemplateOrganizationOutputDtoSimple>>(
    {
      url: Api.ReadPrintOrganizations,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 创建打印组织
/**
 * 创建打印组织
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function createPrintOrganizations(
  dtos: PrintTemplateOrganizationDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.CreatePrintOrganizations,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 删除打印组织
/**
 * 删除打印组织
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function deletePrintOrganizations(
  dtos: PrintTemplateOrganizationDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.DeletePrintOrganizations,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 清除打印组织
/**
 * 清除打印组织
 * @param dtos 输入DTO
 * @param mode 错误消息模型
 */
export function clearPrintOrganizations(
  dtos: PrintOrganizationDto[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintOrganizations,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 根据模板清除打印组织
/**
 * 根据模板清除打印组织
 * @param templateIds 模板编号
 * @param mode 错误消息模型
 */
export function clearPrintOrganizationsByTemplate(
  templateIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintOrganizationsByTemplate,
      params: templateIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
//#region 根据打印清除打印组织
/**
 * 根据打印清除打印组织
 * @param printIds 打印编号
 * @param mode 错误消息模型
 */
export function clearPrintOrganizationsByPrint(
  printIds: (string | bigint)[],
  mode: ErrorMessageMode = 'message',
) {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ClearPrintOrganizationsByPrint,
      params: printIds,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion

//#region 读取打印日志
/**
 * 读取打印日志
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function readPrintLogs(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<PrintLogOutputDto>>(
    {
      url: Api.ReadPrintLogs,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}
//#endregion
