import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { RouteItemOutputDtos, RouteItemOutputDto, RouteItemInputDto } from './model/menuModel';
import { PageRequest, PageData } from '/@/utils/common/types';
import { AjaxResult } from '../model';

/** 菜单模块URL枚举 */
enum Api {
  /** 获取路由项信息 */
  GetRouteItems = '/api/menu/getRouteItems',
  /** 读取路由项信息 */
  RouteItemsRead = '/api/admin/route/read',
  /** 新增路由项信息 */
  RouteItemsCreate = '/api/admin/route/create',
  /** 更新路由项信息 */
  RouteItemsUpdate = '/api/admin/route/update',
  /** 删除路由项信息 */
  RouteItemsDelete = '/api/admin/route/delete',
}

/**
 * 获取路由项信息
 * @param mode 错误消息模型
 */
export function getRouteItems(mode: ErrorMessageMode = 'message') {
  return httpClient.get<RouteItemOutputDtos>(
    {
      url: Api.GetRouteItems,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 读取路由信息
 * @param request 分页请求
 * @param mode 错误消息模型
 */
export function routeItemsRead(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<RouteItemOutputDto>>(
    {
      url: Api.RouteItemsRead,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 新增路由项信息
 * @param dtos DTO信息
 * @param mode 错误消息模型
 */
export function routeItemsCreate(dtos: RouteItemInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.RouteItemsCreate,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 更新路由项信息
 * @param dtos DTO信息
 * @param mode 错误消息模型
 */
export function routeItemsUpdate(dtos: RouteItemInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.RouteItemsUpdate,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

/**
 * 删除路由项信息
 * @param ids 要删除的编号集合
 * @param mode 错误消息模型
 */
export function routeItemsDelete(ids: (string | bigint)[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.RouteItemsDelete,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}
