import { FormSchema } from '/@/components/Table';
import { FormModeEnum } from '/@/enums/formEnum';
import type { AdFetchParams } from './adTable';

/** 高级详情表单属性 */
export interface AdDetailFormProps {
  /** 表单标识 */
  formIndex: string;
  /** 主键字段 */
  keyField: string;
  /** 表单抬头	-	modal 标题 */
  title?: string;
  /** 固定 modal 的宽度 */
  width?: number | string;
  /** 固定 modal 的高度 */
  height?: number;
  /** modal 的最小高度 */
  minHeight?: number;
  /** 是否开启拖拽 */
  draggable?: boolean;
  /** 是否开启自适应高度，开启后会跟随屏幕变化自适应内容，并出现滚动条 */
  useWrapper?: boolean;
  /** 开启是适应高度后，如果超过屏幕高度，底部和顶部会保持一样的间距，该参数可以用来缩小底部的间距 */
  wrapperFooterOffset?: number;
  /** 是否可以进行全屏 */
  canFullscreen?: boolean;
  /** 默认全屏 */
  defaultFullscreen?: boolean;
  /** loading 状态 */
  loading?: boolean;
  /** loading 文本 */
  loadingTip?: string;
  /** 显示关闭按钮 */
  showCancelBtn?: boolean;
  /** 显示确认按钮 */
  showOkBtn?: boolean;
  /** 标题右侧提示文本 */
  helpMessage?: string | string[];
  /** 是否居中弹窗 */
  centered?: boolean;
  /** 关闭按钮文本 */
  cancelText?: string;
  /** 确认按钮文本 */
  okText?: string;
  /** 表单架构 */
  formSchema?: FormSchema[];
  /** 显示表单架构信息 */
  showFormSchemaInfo?: boolean;
  /** 扩展 form 组件，增加 label 宽度，表单内所有组件适用，可以单独在某个项覆盖或者禁用 */
  labelWidth?: number | string;
  /** label 布局 */
  labelAlign?: 'left' | 'right';
  /** 紧凑类型表单，减少 margin-bottom */
  compact?: boolean;
  /** 向表单内所有组件传递 size 参数,自定义组件需自行实现 size 接收 */
  size?: 'default' | 'small' | 'large';
  /** 向表单内所有组件传递 disabled 属性，自定义组件需自行实现 disabled 接收 */
  disabled?: boolean;
  /** 实体新增接口请求对象 */
  createApi?: (params: any[]) => Promise<any>;
  /** 实体更新接口请求对象 */
  updateApi?: (params: any[]) => Promise<any>;
  /** 实体删除接口请求对象 */
  deleteApi?: (params: any[]) => Promise<any>;
  /** 关闭回调，返回true关闭窗体 */
  closeFunc?: (formMode: FormModeEnum, record: any) => Promise<boolean>;
  /** 提交回调，返回true关闭窗体 */
  submitFunc?: (formMode: FormModeEnum, record: any) => Promise<boolean>;
  /** 重新加载表格数据方法 */
  reloadFunc?: (opt?: AdFetchParams) => Promise<void>;
}
