/**
 * @description: 请求返回状态枚举
 */
export enum ResultStatusEnum {
  // 2XX
  /** 成功 */
  Success = 200,

  // 4XX
  /** 错误 */
  Error = 400,
  /** 未登录 */
  Unauthorized = 401,
  /** 已登录但权限不足 */
  Forbidden = 403,
  /** 资源未找到 */
  NotFound = 404,
  /** 不允许 */
  NotAllowed = 405,
  /** 不支持 */
  Unsupported = 415,
  /** 资源被锁定 */
  Locked = 423,

  // 5XX
  /** 服务器内部错误 */
  InternalError = 500,
  /** 功能未实现 */
  NotImplemented = 501,
  /** 网络错误 */
  BadGateway = 502,
  /** 服务不可用，服务器暂时过载或维护 */
  ServiceUnavailable = 503,
  /** 网络超时 */
  GatewayTimeout = 504,
  /** http版本不支持该请求 */
  HttpVersionNotSupported = 505,
}

/**
 * @description: 请求方法（request method）
 */
export enum RequestEnum {
  /** Get */
  GET = 'GET',
  /** Post */
  POST = 'POST',
  /** Put */
  PUT = 'PUT',
  /** Delete */
  DELETE = 'DELETE',
}

/**
 * @description: 内容类型（content Type）
 */
export enum ContentTypeEnum {
  /** json */
  JSON = 'application/json;charset=UTF-8',
  /** form-data qs */
  FORM_URLENCODED = 'application/x-www-form-urlencoded;charset=UTF-8',
  /** form-data upload */
  FORM_DATA = 'multipart/form-data;charset=UTF-8',
}
