import { EnumSchema } from '/@/utils/common/types';
import { PresetColorEnum } from '/@/enums/colorEnum';
import { useI18n } from '/@/hooks/web/useI18n';

//#region 报表数据源模式枚举
/** 报表数据源模式枚举 */
export enum ReportDataSourceModeEnum {
  /** 推 */
  Push = 1,
  /** 拉 */
  Pull = 2,
}
//#endregion

/** 数据源模式实体 */
export class ReportDataSourceModeEntity {
  /** 数据源模式 */
  DataSourceMode: ReportDataSourceModeEnum;
  /** 显示描述 */
  Display: string;
  /** 颜色 */
  Color?: PresetColorEnum | string;

  constructor(dataSourceMode: ReportDataSourceModeEnum, color?: PresetColorEnum | string) {
    const { t } = useI18n();
    this.DataSourceMode = dataSourceMode;
    this.Color = color;
    switch (dataSourceMode) {
      case ReportDataSourceModeEnum.Push:
        // this.Display = '推';
        this.Display = t('enum.reportDataSourceMode.push');
        this.Color = this.Color ? this.Color : PresetColorEnum.Green;
        break;
      case ReportDataSourceModeEnum.Pull:
        // this.Display = '拉';
        this.Display = t('enum.reportDataSourceMode.pull');
        this.Color = this.Color ? this.Color : PresetColorEnum.Blue;
        break;
    }
  }
}

//#region 数据源模式枚举架构
/**
 * 数据源模式枚举架构
 */
export function getReportDataSourceModeEnumSchema(enableTag = true): EnumSchema[] {
  const enumSchema: EnumSchema[] = [];
  const entities: ReportDataSourceModeEntity[] = [
    new ReportDataSourceModeEntity(ReportDataSourceModeEnum.Push),
    new ReportDataSourceModeEntity(ReportDataSourceModeEnum.Pull),
  ];
  entities.forEach((item) => {
    enumSchema.push({
      key: item.DataSourceMode as number,
      label: item.Display,
      value: item.DataSourceMode as number,
      tag: enableTag,
      tagColor: item.Color,
    });
  });
  return enumSchema;
}
//#endregion
