import type { AppRouteRecordRaw, AppRouteModule } from '/@/router/types';

import { PAGE_NOT_FOUND_ROUTE, REDIRECT_ROUTE } from '/@/router/routes/basic';

import { mainOutRoutes } from './mainOut';
import { PageEnum } from '/@/enums/pageEnum';
import { t } from '/@/hooks/web/useI18n';

// import.meta.glob() 直接引入所有的模块 Vite 独有的功能
const modules = import.meta.glob('./modules/**/*.ts', { eager: true });
const routeModuleList: AppRouteModule[] = [];

// 加入到路由集合中
Object.keys(modules).forEach((key) => {
  const mod = (modules as Recordable)[key].default || {};
  const modList = Array.isArray(mod) ? [...mod] : [mod];
  routeModuleList.push(...modList);
});

export const asyncRoutes = [PAGE_NOT_FOUND_ROUTE, ...routeModuleList];

// 根路由
export const RootRoute: AppRouteRecordRaw = {
  path: '/',
  name: 'Root',
  redirect: PageEnum.BASE_HOME,
  meta: {
    title: 'Root',
  },
};

export const LoginRoute: AppRouteRecordRaw = {
  path: '/login',
  name: 'Login',
  component: () => import('/@/views/sys/login/Login.vue'),
  meta: {
    title: t('routes.basic.login'),
  },
};

export const CofirmEmailRoute: AppRouteRecordRaw = {
  path: PageEnum.BASE_CONFIRM_EMAIL,
  name: 'ConfirmEmail',
  component: () => import('/@/views/sys/email/ConfirmEmail.vue'),
  meta: {
    title: t('routes.basic.confirmEmail'),
  },
};

export const ResetPasswordRoute: AppRouteRecordRaw = {
  path: PageEnum.BASE_RESET_PASSWORD,
  name: 'ResetPassword',
  component: () => import('/@/views/sys/email/ResetPassword.vue'),
  meta: {
    title: t('routes.basic.resetPassword'),
  },
};

export const OAuthCallbackRoute: AppRouteRecordRaw = {
  path: PageEnum.BASE_OAUTH_CALLBACK,
  name: 'OAuthCallback',
  component: () => import('/@/views/sys/oauth-callback/index.vue'),
  meta: {
    title: t('routes.basic.oAuthLogin'),
  },
};

// Basic routing without permission
// 未经许可的基本路由
export const basicRoutes = [
  CofirmEmailRoute,
  ResetPasswordRoute,
  OAuthCallbackRoute,
  LoginRoute,
  RootRoute,
  ...mainOutRoutes,
  REDIRECT_ROUTE,
  PAGE_NOT_FOUND_ROUTE,
];
