import type { AppRouteModule } from '/@/router/types';

import { LAYOUT, getParentLayout } from '/@/router/constant';
import { t } from '/@/hooks/web/useI18n';

const system: AppRouteModule = {
  path: '/system',
  name: 'System',
  component: LAYOUT,
  redirect: '/system/identity',
  meta: {
    orderNo: 2000,
    icon: 'ion:settings-outline',
    title: t('routes.system.moduleName'),
    roles: [
      'File.UploadLogo',
      'File.DeleteLogo',
      'Admin.Systems.Settings.SetAppTitle',
      'Admin.Systems.Settings.SetAppDescription',
      'Admin.Menu.Route.Read',
      'Admin.Systems.Pack.Read',
      'Admin.Identity.LoginLog.Read',
      'Admin.Identity.User.Read',
      'Admin.Identity.Role.Read',
      'Admin.Identity.Organization.Read',
      'Admin.Auth.Module.Read',
      'Admin.Auth.Function.Read',
      'Admin.Auth.EntityInfo.Read',
      'Admin.Auth.RoleEntity.Read',
      'Admin.Auth.UserEntity.Read',
    ],
  },
  children: [
    // =============================偏好设置 start=============================
    {
      path: 'preference',
      name: 'PreferencePage',
      component: () => import('/@/views/system/preference/index.vue'),
      meta: {
        icon: 'ic:outline-room-preferences',
        title: t('routes.system.preference.title'),
        ignoreKeepAlive: false,
        roles: [
          'File.UploadLogo',
          'File.DeleteLogo',
          'Admin.Systems.Settings.SetAppTitle',
          'Admin.Systems.Settings.SetAppDescription',
        ],
      },
    },
    // =============================偏好设置 end===============================
    // =============================菜单管理 start=============================
    {
      path: 'menu',
      name: 'MenuPage',
      component: () => import('/@/views/system/menu/MenuPage.vue'),
      meta: {
        icon: 'ri:menu-add-fill',
        title: t('routes.system.menu.title'),
        ignoreKeepAlive: false,
        roles: ['Admin.Menu.Route.Read'],
      },
    },
    // =============================菜单管理 end===============================
    // =============================系统模块包 start=============================
    {
      path: 'pack',
      name: 'PackPage',
      component: () => import('/@/views/system/pack/PackPage.vue'),
      meta: {
        icon: 'uil:package',
        title: t('routes.system.pack.title'),
        ignoreKeepAlive: false,
        roles: ['Admin.Systems.Pack.Read'],
      },
    },
    // =============================系统模块包 end===============================
    // =============================登录日志 start=============================
    {
      path: 'loginlog',
      name: 'LoginLogPage',
      component: () => import('/@/views/system/loginlog/LoginLog.vue'),
      meta: {
        icon: 'mdi:login-variant',
        title: t('routes.system.loginlog.title'),
        ignoreKeepAlive: false,
        roles: ['Admin.Identity.LoginLog.Read'],
      },
    },
    // =============================登录日志 end===============================
    // =============================字典管理 start=============================
    {
      path: 'dict',
      name: 'DictManagePage',
      component: () => import('/@/views/system/dicts/DictPage.vue'),
      meta: {
        icon: 'arcticons:colordict',
        title: '字典管理',
        roles: ['Admin.Systems.Dict.ReadDict'],
      }  
    },
    // =============================字典管理 end=============================
    // =============================身份认证 start=============================
    {
      path: 'identity',
      name: 'IdentityPage',
      component: getParentLayout('IdentityPage'),
      redirect: '/system/identity/user',
      meta: {
        icon: 'lucide:users',
        title: t('routes.system.identity.title'),
        roles: [
          'Admin.Identity.User.Read',
          'Admin.Identity.Role.Read',
          'Admin.Identity.Organization.Read',
        ],
      },
      children: [
        {
          path: 'user',
          name: 'UserPage',
          component: () => import('/@/views/system/identity/user/UserPage.vue'),
          meta: {
            icon: 'la:users-cog',
            title: t('routes.system.identity.user.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Identity.User.Read'],
          },
        },
        {
          path: 'role',
          name: 'RolePage',
          component: () => import('/@/views/system/identity/role/RolePage.vue'),
          meta: {
            icon: 'carbon:user-identification',
            title: t('routes.system.identity.role.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Identity.Role.Read'],
          },
        },
        {
          path: 'organization',
          name: 'OrganizationPage',
          component: () => import('/@/views/system/identity/organization/OrganizationPage.vue'),
          meta: {
            icon: 'clarity:organization-line',
            title: t('routes.system.identity.organization.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Identity.Organization.Read'],
          },
        },
      ],
    },
    // =============================身份认证 end=============================
    // =============================权限安全 start=============================
    {
      path: 'authorization',
      name: 'AuthorizationPage',
      component: getParentLayout('AuthorizationPage'),
      redirect: '/system/authorization/module',
      meta: {
        icon: 'ic:outline-verified-user',
        title: t('routes.system.authorization.title'),
        roles: [
          'Admin.Auth.Module.Read',
          'Admin.Auth.Function.Read',
          'Admin.Auth.EntityInfo.Read',
          'Admin.Auth.RoleEntity.Read',
          'Admin.Auth.UserEntity.Read',
        ],
      },
      children: [
        {
          path: 'module',
          name: 'ModulePage',
          component: () => import('/@/views/system/authorization/module/ModulePage.vue'),
          meta: {
            icon: 'ri:sound-module-fill',
            title: t('routes.system.authorization.module.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Auth.Module.Read'],
          },
        },
        {
          path: 'function',
          name: 'FunctionPage',
          component: () => import('/@/views/system/authorization/function/FunctionPage.vue'),
          meta: {
            icon: 'grommet-icons:action',
            title: t('routes.system.authorization.function.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Auth.Function.Read'],
          },
        },
        {
          path: 'entityinfo',
          name: 'EntityInfoPage',
          component: () => import('/@/views/system/authorization/entityinfo/EntityInfoPage.vue'),
          meta: {
            icon: 'carbon:data-view',
            title: t('routes.system.authorization.entityInfo.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Auth.EntityInfo.Read'],
          },
        },
        {
          path: 'roleentity',
          name: 'RoleEntityPage',
          component: () => import('/@/views/system/authorization/roleentity/RoleEntityPage.vue'),
          meta: {
            icon: 'icon-park-outline:data-display',
            title: t('routes.system.authorization.roleEntity.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Auth.RoleEntity.Read'],
          },
        },
        {
          path: 'userentity',
          name: 'UserEntityPage',
          component: () => import('/@/views/system/authorization/userentity/UserEntityPage.vue'),
          meta: {
            icon: 'icon-park-outline:data-user',
            title: t('routes.system.authorization.userEntity.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Auth.UserEntity.Read'],
          },
        },
      ],
    },
    // =============================权限安全 end=============================
    // =============================审计管理 start=============================
    {
      path: 'audit',
      name: 'AuditPage',
      component: getParentLayout('AuditPage'),
      redirect: '/system/audit/auditoperation',
      meta: {
        icon: 'codicon:preview',
        title: t('routes.system.audit.title'),
        roles: ['Admin.Audit.AuditOperation.Read', 'Admin.Audit.AuditEntity.Read'],
      },
      children: [
        {
          path: 'auditoperation',
          name: 'AuditOperationPage',
          component: () => import('/@/views/system/audit/auditoperation/AuditOperationPage.vue'),
          meta: {
            icon: 'carbon:touch-interaction',
            title: t('routes.system.audit.auditOperation.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Audit.AuditOperation.Read'],
          },
        },
        {
          path: 'auditentity',
          name: 'AuditEntityPage',
          component: () => import('/@/views/system/audit/auditentity/AuditEntityPage.vue'),
          meta: {
            icon: 'fluent:database-link-24-regular',
            title: t('routes.system.audit.auditEntity.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Audit.AuditEntity.Read'],
          },
        },
      ],
    },
    // =============================审计管理 end=============================
    // =============================报表管理 start=============================
    {
      path: 'report',
      name: 'ReportPage',
      component: getParentLayout('ReportPage'),
      redirect: '/system/report/print',
      meta: {
        icon: 'iconoir:stats-report',
        title: t('routes.system.report.title'),
        roles: [
          'Admin.Report.Print.ReadPrints',
          'Admin.Report.Print.ReadTemplates',
          'Admin.Report.Print.ReadPrintLogs',
        ],
      },
      children: [
        {
          path: 'print',
          name: 'PrintPage',
          component: getParentLayout('PrintPage'),
          redirect: '/system/report/print/printsetup',
          meta: {
            icon: 'clarity:printer-line',
            title: t('routes.system.report.print.title'),
            roles: [
              'Admin.Report.Print.ReadPrints',
              'Admin.Report.Print.ReadTemplates',
              'Admin.Report.Print.ReadPrintLogs',
            ],
          },
          children: [
            {
              path: 'printsetup',
              name: 'PrintSetupPage',
              component: () => import('/@/views/system/report/print/printsetup/index.vue'),
              meta: {
                icon: 'mdi:printer-pos-cog-outline',
                title: t('routes.system.report.print.printSetup.title'),
                ignoreKeepAlive: false,
                roles: ['Admin.Report.Print.ReadPrints', 'Admin.Report.Print.ReadTemplates'],
              },
            },
            {
              path: 'printlog',
              name: 'PrintLogPage',
              component: () => import('/@/views/system/report/print/printlog/index.vue'),
              meta: {
                icon: 'mdi:printer-pos-play-outline',
                title: t('routes.system.report.print.printLog.title'),
                ignoreKeepAlive: false,
                roles: ['Admin.Report.Print.ReadPrintLogs'],
              },
            },
          ],
        },
      ],
    },
    // =============================报表管理 end=============================
    // =============================消息管理 start=============================
    {
      path: 'message',
      name: 'Message',
      component: getParentLayout('Message'),
      redirect: '/system/message/message',
      meta: {
        icon: 'icon-park-outline:message-unread',
        title: t('routes.system.message.title'),
        roles: [
          'Admin.Msg.Message.Read',
          'Admin.Msg.QueryMessage.Read',
          'Admin.Msg.TemplateMessage.Read',
        ],
      },
      children: [
        {
          path: 'message',
          name: 'MessagePage',
          component: () => import('/@/views/system/message/message/index.vue'),
          meta: {
            icon: 'carbon:email-new',
            title: t('routes.system.message.message.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Msg.Message.Read'],
          },
        },
        {
          path: 'querymessage',
          name: 'QueryMessagePage',
          component: () => import('/@/views/system/message/querymessage/index.vue'),
          meta: {
            icon: 'carbon:sql',
            title: t('routes.system.message.queryMessage.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Msg.QueryMessage.Read'],
          },
        },
        {
          path: 'templatemessage',
          name: 'TemplateMessagePage',
          component: () => import('/@/views/system/message/templatemessage/index.vue'),
          meta: {
            icon: 'carbon:message-queue',
            title: t('routes.system.message.templateMessage.title'),
            ignoreKeepAlive: false,
            roles: ['Admin.Msg.TemplateMessage.Read'],
          },
        },
      ],
    },
    // =============================消息管理 end=============================
  ],
};

export default system;
