import type { AppRouteModule } from '/@/router/types';
import { LAYOUT, getParentLayout } from '/@/router/constant';

const vinno: AppRouteModule = {
  path: '/vinno',
  name: 'Vinno',
  component: LAYOUT,
  redirect: '/vinno/brand',
  meta: {
    icon: 'clarity:rack-server-solid',
    title: 'WMS',
    orderNo: 4000,
  },
  children: [
    {
      path: 'settings',
      name: 'SettingsPage',
      component: getParentLayout('SettingsPage'),
      meta: {
        icon: 'icon-park:setting-two',
        title: '基础配置',
        roles: [
          'Admin.Wms.Material.ReadTree',
          'Admin.Wms.WareHouse.Read',
          'Admin.Wms.WareHouseArea.Read',
          'Admin.Wms.WareHouseAreaPos.Read',
        ],
      },
      children: [
        {
          path: 'materialcategorys',
          name: 'MaterialCategoryPage',
          component: () => import('/@/views/vinno/materialcategorys/MaterialCategoryPage.vue'),
          meta: {
            icon: '',
            title: '物料分类',
            roles: ['Admin.Wms.MaterialCategory.ReadTree'],
          },
        },
        {
          path: 'wareHouses',
          name: 'WareHousesPage',
          component: getParentLayout('WareHousesPage'),
          meta: {
            icon: '',
            title: '仓库配置',
            roles: [
              'Admin.Wms.WareHouse.Read',
              'Admin.Wms.WareHouseArea.Read',
              'Admin.Wms.WareHouseAreaPos.Read',
            ],
          },
          children: [
            {
              path: 'warehouse',
              name: 'WareHousePage',
              component: () => import('/@/views/vinno/warehouses/warehouse/WareHousePage.vue'),
              meta: {
                title: '仓库',
                roles: ['Admin.Wms.WareHouse.Read'],
              },
            },
            {
              path: 'warehousearea',
              name: 'WareHouseAreaPage',
              component: () =>
                import('/@/views/vinno/warehouses/warehousearea/WareHouseAreaPage.vue'),
              meta: {
                title: '库区',
                roles: ['Admin.Wms.WareHouseArea.Read'],
              },
            },
            {
              path: 'warehouseareapos',
              name: 'WareHouseAreaPosPage',
              component: () =>
                import('/@/views/vinno/warehouses/warehouseareapos/WareHouseAreaPosPage.vue'),
              meta: {
                title: '库位',
                roles: ['Admin.Wms.WareHouseAreaPos.Read'],
              },
            },
          ],
        },
      ],
    },
    {
      path: 'ipns',
      name: 'IPNsPage',
      component: () => import('/@/views/vinno/ipns/IPNPage.vue'),
      meta: {
        icon: 'tabler:number',
        title: 'IPN',
        roles: ['Admin.Wms.IPN.Read'],
      },
    },
    {
      path: 'material',
      name: 'MaterialPage',
      component: () => import('/@/views/vinno/materials/material/MaterialPage.vue'),
      meta: {
        icon: 'lucide:warehouse',
        title: '库存',
        roles: ['Admin.Wms.Material.Read'],
      },
    },
    {
      path: 'materialinstorage',
      name: 'MaterialInStoragePage',
      component: () =>
        import('/@/views/vinno/materials/materialinstorage/MaterialInStoragePage.vue'),
      meta: {
        icon: 'maki:warehouse',
        title: '入库',
        roles: ['Admin.Wms.MaterialInStorage.Read'],
      },
    },
    {
      path: 'materialoutstorage',
      name: 'MaterialOutStoragePage',
      component: () =>
        import('/@/views/vinno/materials/materialoutstorage/MaterialOutStoragePage.vue'),
      meta: {
        icon: 'streamline:shipping-transfer-cart-package-box-fulfillment-cart-warehouse-shipping-delivery',
        title: '出库',
        roles: ['Admin.Wms.MaterialOutStorage.Read'],
      },
    },
  ],
};

export default vinno;
