import type { RouteRecordRaw, RouteMeta } from 'vue-router';
import { defineComponent } from 'vue';

/**
 * 组件
 */
export type Component<T = any> =
  | ReturnType<typeof defineComponent>
  | (() => Promise<typeof import('*.vue')>)
  | (() => Promise<T>);

/** 应用程序路由原始记录 */
// @ts-ignore
export interface AppRouteRecordRaw extends Omit<RouteRecordRaw, 'meta'> {
  /** 路由记录的名称（Name for the route record） */
  name: string;
  /** 路由单元 */
  meta: RouteMeta;
  /** 当URL与此路由匹配时要显示的组件（Component to display when the URL matches this route） */
  component?: Component | string;
  /** URL与此路由匹配时要显示的组件。允许使用命名视图。（Components to display when the URL matches this route. Allow using named views.） */
  components?: Component;
  /** 嵌套路由的数组（Array of nested routes） */
  children?: AppRouteRecordRaw[];
  /** 属性 */
  props?: Recordable;
  /** 完整路径 */
  fullPath?: string;
}

/** 菜单标签 */
export interface MenuTag {
  /** 类型 */
  type?: 'primary' | 'error' | 'warn' | 'success';
  /** 内容 */
  content?: string;
  /** 为true则显示小圆点 */
  dot?: boolean;
}

/** 菜单 */
export interface Menu {
  /** 菜单名 */
  name: string;
  /** 菜单图标,如果没有，则会尝试使用route.meta.icon */
  icon?: string;
  /** 菜单路径 */
  path: string;
  /** 路径包含参数，自动分配。（path contains param, auto assignment.） */
  paramPath?: string;
  /** 是否禁用 */
  disabled?: boolean;
  /** 子菜单 */
  children?: Menu[];
  /** 菜单排序。越大排名越后面 */
  orderNo?: number;
  /** 角色 */
  roles?: string[];
  /** 单元 */
  meta?: Partial<RouteMeta>;
  /** 菜单标签 */
  tag?: MenuTag;
  /** 隐藏菜单 */
  hideMenu?: boolean;
}

/** 菜单模块 */
export interface MenuModule {
  /** 菜单排序。越大排名越后面 */
  orderNo?: number;
  /** 菜单 */
  menu: Menu;
}

/** 应用程序路由模块 */
// export type AppRouteModule = RouteModule | AppRouteRecordRaw;
export type AppRouteModule = AppRouteRecordRaw;
