import type { DropMenu } from '../components/Dropdown';
import type { LocaleSetting, LocaleType } from '/#/config';

/** 本地化语言类型
 * ar_AE：阿拉伯语 Arabic
 * az_AZ：阿塞拜疆语 Azerbaijani
 * bg_BG：保加利亚语 Bulgarian
 * bn_BD：孟加拉语 Bengali
 * ca_CA：加泰罗尼亚语 Catalan
 * cs_CZ：捷克语 Czech
 * cy_GB：威尔士语 Welsh
 * da_DK：丹麦语（丹麦）Danish (Denmark)
 * de_DE：德语 German
 * dv_DV：迪维希语 Dhivehi
 * el_GR：希腊语 Greek
 * en_US：英语（美国）English (United States)
 * en_GB：英语（英国）English (United Kingdom)
 * es_ES：西班牙语 Spanish
 * et_EE：爱沙尼亚语 Estonian
 * eu_ES：巴斯克语 Basque
 * fa_IR：波斯语 Persian
 * fi_FI：芬兰语（芬兰）Finnish (Finland)
 * fr_FR：法语 French
 * ga_IE：爱尔兰语 Irish
 * gl_ES：加利西亚语 Galician
 * he_IL：希伯来语（以色列）Hebrew (Israel)
 * hi_IN：印地语 Hindi
 * hr_HR：克罗地亚语 Croatian
 * hu_HU：匈牙利语 Hungarian
 * hy_AM：亚美尼亚语 Armenian
 * id_ID：印度尼西亚语 Indonesian
 * is_IS：冰岛语 Icelandic
 * it_IT：意大利语 Italian
 * ja_JP：日语 Japanese
 * kab_DZ：卡拜尔语 Kabyle
 * kk_KZ：哈萨克语 Kazakh
 * ko_KR：朝鲜语（南韩）Korean
 * ckb_IR：库尔德语 Kurdish
 * lt_LT：立陶宛语 Lithuanian
 * lv_LV：拉脱维亚语 Latvian
 * nb_NB：挪威博克马尔语 Norwegian Bokmal
 * nb_NO：挪威语（挪威）Norwegian (Norway)
 * ne_NP：尼泊尔语 Nepali
 * nl_NL：荷兰语（荷兰）Dutch (Netherlands)
 * nl_BE：荷兰语（比利时）Dutch (Belgium)
 * oc_OC：奥克语 Occitan
 * pl_PL：波兰语 Polish
 * pt_PT：葡萄牙语 Portuguese
 * pt_BR：葡萄牙语（巴西）Portuguese (Brazil)
 * ro_RO：罗马尼亚语 Romanian
 * ru_RU：俄语 Russian
 * sk_SK：斯洛伐克语 Slovak
 * sl_SL：斯洛文尼亚语 Slovenian
 * sq_AL：阿尔巴尼亚语 Albanian
 * sr_cyrl_RS：塞尔维亚语（西里尔文） Serbian
 * sv_SE：瑞典语 Swedish
 * ta_IN：泰米尔语 Tamil
 * tg_TJ：塔吉克语 Tajik
 * th_TH：泰语 Thai
 * tr_TR：土耳其语 Turkish
 * ug_CN：维吾尔语 Uyghur
 * uk_UK：乌克兰语 Ukrainian
 * vi_VN：越南语 Vietnamese
 * zh_CN：简体中文 Chinese
 * zh_TW：繁体中文（台湾）Traditional Chinese (Tai Wan)
 */
export const LOCALE: { [key: string]: LocaleType } = {
  /** 阿拉伯语 Arabic */
  AR_AE: 'ar_AE',
  /** 阿塞拜疆语 Azerbaijani */
  AZ_AZ: 'az_AZ',
  /** 保加利亚语 Bulgarian */
  BG_BG: 'bg_BG',
  /** 孟加拉语 Bengali */
  BN_BD: 'bn_BD',
  /** 加泰罗尼亚语 Catalan */
  CA_CA: 'ca_CA',
  /** 捷克语 Czech */
  CS_CZ: 'cs_CZ',
  /** 威尔士语 Welsh */
  CY_GB: 'cy_GB',
  /** 丹麦语（丹麦）Danish (Denmark) */
  DA_DK: 'da_DK',
  /** 德语 German */
  DE_DE: 'de_DE',
  /** 迪维希语 Dhivehi */
  DV_DV: 'dv_DV',
  /** 希腊语 Greek */
  EL_GR: 'el_GR',
  /** 英语（美国）English (United States) */
  EN_US: 'en_US',
  /** 英语（英国）English (United Kingdom) */
  EN_GB: 'en_GB',
  /** 西班牙语 Spanish */
  ES_ES: 'es_ES',
  /** 爱沙尼亚语 Estonian */
  ET_EE: 'et_EE',
  /** 巴斯克语 Basque */
  EU_ES: 'eu_ES',
  /** 波斯语 Persian */
  FA_IR: 'fa_IR',
  /** 芬兰语（芬兰）Finnish (Finland) */
  FI_FI: 'fi_FI',
  /** 法语 French */
  FR_FR: 'fr_FR',
  /** 爱尔兰语 Irish */
  GA_IE: 'ga_IE',
  /** 加利西亚语 Galician */
  GL_ES: 'gl_ES',
  /** 希伯来语（以色列）Hebrew (Israel) */
  HE_IL: 'he_IL',
  /** 印地语 Hindi */
  HI_IN: 'hi_IN',
  /** 克罗地亚语 Croatian */
  HR_HR: 'hr_HR',
  /** 匈牙利语 Hungarian */
  HU_HU: 'hu_HU',
  /** 亚美尼亚语 Armenian */
  HY_AM: 'hy_AM',
  /** 印度尼西亚语 Indonesian */
  ID_ID: 'id_ID',
  /** 冰岛语 Icelandic */
  IS_IS: 'is_IS',
  /** 意大利语 Italian */
  IT_IT: 'it_IT',
  /** 日语 Japanese */
  JA_JP: 'ja_JP',
  /** 卡拜尔语 Kabyle */
  KAB_DZ: 'kab_DZ',
  /** 哈萨克语 Kazakh */
  KK_KZ: 'kk_KZ',
  /** 朝鲜语（南韩）Korean */
  KO_KR: 'ko_KR',
  /** 库尔德语 Kurdish */
  CKB_IR: 'ckb_IR',
  /** 立陶宛语 Lithuanian */
  LT_LT: 'lt_LT',
  /** 拉脱维亚语 Latvian */
  LV_LV: 'lv_LV',
  /** 挪威博克马尔语 Norwegian Bokmal */
  NB_NB: 'nb_NB',
  /** 挪威语（挪威）Norwegian (Norway) */
  NB_NO: 'nb_NO',
  /** 尼泊尔语 Nepali */
  NE_NP: 'ne_NP',
  /** 荷兰语（荷兰）Dutch (Netherlands) */
  NL_NL: 'nl_NL',
  /** 荷兰语（比利时）Dutch (Belgium) */
  NL_BE: 'nl_BE',
  /** 奥克语 Occitan */
  OC_OC: 'oc_OC',
  /** 波兰语 Polish */
  PL_PL: 'pl_PL',
  /** 葡萄牙语 Portuguese */
  PT_PT: 'pt_PT',
  /** 葡萄牙语（巴西）Portuguese (Brazil) */
  PT_BR: 'pt_BR',
  /** 罗马尼亚语 Romanian */
  RO_RO: 'ro_RO',
  /** 俄语 Russian */
  RU_RU: 'ru_RU',
  /** 斯洛伐克语 Slovak */
  SK_SK: 'sk_SK',
  /** 斯洛文尼亚语 Slovenian */
  SL_SL: 'sl_SL',
  /** 阿尔巴尼亚语 Albanian */
  SQ_AL: 'sq_AL',
  /** 塞尔维亚语（西里尔文） Serbian */
  SR_CYRL_RS: 'sr_cyrl_RS',
  /** 瑞典语 Swedish */
  SV_SE: 'sv_SE',
  /** 泰米尔语 Tamil */
  TA_IN: 'ta_IN',
  /** 塔吉克语 Tajik */
  TG_TJ: 'tg_TJ',
  /** 泰语 Thai */
  TH_TH: 'th_TH',
  /** 土耳其语 Turkish */
  TR_TR: 'tr_TR',
  /** 维吾尔语 Uyghur */
  UG_CN: 'ug_CN',
  /** 乌克兰语 Ukrainian */
  UK_UK: 'uk_UK',
  /** 越南语 Vietnamese */
  VI_VN: 'vi_VN',
  /** 简体中文 Chinese */
  ZH_CN: 'zh_CN',
  /** 繁体中文（台湾）Traditional Chinese (Tai Wan) */
  ZH_TW: 'zh_TW',
};

/** 多语言配置 */
export const localeSetting: LocaleSetting = {
  /** 是否显示语言选择器 */
  showPicker: true,
  /** 当前语言（Current language） */
  locale: LOCALE.ZH_CN,
  /** 默认语言（default language） */
  fallback: LOCALE.ZH_CN,
  /** 允许的语言（available Locales） */
  availableLocales: [
    LOCALE.AR_AE, // 阿拉伯语 Arabic
    LOCALE.AZ_AZ, // 阿塞拜疆语 Azerbaijani
    LOCALE.BG_BG, // 保加利亚语 Bulgarian
    LOCALE.BN_BD, // 孟加拉语 Bengali
    LOCALE.CA_CA, // 加泰罗尼亚语 Catalan
    LOCALE.CS_CZ, // 捷克语 Czech
    LOCALE.CY_GB, // 威尔士语 Welsh
    LOCALE.DA_DK, // 丹麦语（丹麦）Danish (Denmark)
    LOCALE.DE_DE, // 德语 German
    LOCALE.DV_DV, // 迪维希语 Dhivehi
    LOCALE.EL_GR, // 希腊语 Greek
    LOCALE.EN_US, // 英语（美国）English (United States)
    LOCALE.EN_GB, // 英语（英国）English (United Kingdom)
    LOCALE.ES_ES, // 西班牙语 Spanish
    LOCALE.ET_EE, // 爱沙尼亚语 Estonian
    LOCALE.EU_ES, // 巴斯克语 Basque
    LOCALE.FA_IR, // 波斯语 Persian
    LOCALE.FI_FI, // 芬兰语（芬兰）Finnish (Finland)
    LOCALE.FR_FR, // 法语 French
    LOCALE.GA_IE, // 爱尔兰语 Irish
    LOCALE.GL_ES, // 加利西亚语 Galician
    LOCALE.HE_IL, // 希伯来语（以色列）Hebrew (Israel)
    LOCALE.HI_IN, // 印地语 Hindi
    LOCALE.HR_HR, // 克罗地亚语 Croatian
    LOCALE.HU_HU, // 匈牙利语 Hungarian
    LOCALE.HY_AM, // 亚美尼亚语 Armenian
    LOCALE.ID_ID, // 印度尼西亚语 Indonesian
    LOCALE.IS_IS, // 冰岛语 Icelandic
    LOCALE.IT_IT, // 意大利语 Italian
    LOCALE.JA_JP, // 日语 Japanese
    LOCALE.KAB_DZ, // 卡拜尔语 Kabyle
    LOCALE.KK_KZ, // 哈萨克语 Kazakh
    LOCALE.KO_KR, // 朝鲜语（南韩）Korean
    LOCALE.CKB_IR, // 库尔德语 Kurdish
    LOCALE.LT_LT, // 立陶宛语 Lithuanian
    LOCALE.LV_LV, // 拉脱维亚语 Latvian
    LOCALE.NB_NB, // 挪威博克马尔语 Norwegian Bokmal
    LOCALE.NB_NO, // 挪威语（挪威）Norwegian (Norway)
    LOCALE.NE_NP, // 尼泊尔语 Nepali
    LOCALE.NL_NL, // 荷兰语（荷兰）Dutch (Netherlands)
    LOCALE.NL_BE, // 荷兰语（比利时）Dutch (Belgium)
    LOCALE.OC_OC, // 奥克语 Occitan
    LOCALE.PL_PL, // 波兰语 Polish
    LOCALE.PT_PT, // 葡萄牙语 Portuguese
    LOCALE.PT_BR, // 葡萄牙语（巴西）Portuguese (Brazil)
    LOCALE.RO_RO, // 罗马尼亚语 Romanian
    LOCALE.RU_RU, // 俄语 Russian
    LOCALE.SK_SK, // 斯洛伐克语 Slovak
    LOCALE.SL_SL, // 斯洛文尼亚语 Slovenian
    LOCALE.SQ_AL, // 阿尔巴尼亚语 Albanian
    LOCALE.SR_CYRL_RS, // 塞尔维亚语（西里尔文） Serbian
    LOCALE.SV_SE, // 瑞典语 Swedish
    LOCALE.TA_IN, // 泰米尔语 Tamil
    LOCALE.TG_TJ, // 塔吉克语 Tajik
    LOCALE.TH_TH, // 泰语 Thai
    LOCALE.TR_TR, // 土耳其语 Turkish
    LOCALE.UG_CN, // 维吾尔语 Uyghur
    LOCALE.UK_UK, // 乌克兰语 Ukrainian
    LOCALE.VI_VN, // 越南语 Vietnamese
    LOCALE.ZH_CN, // 简体中文 Chinese
    LOCALE.ZH_TW, // 繁体中文（台湾）Traditional Chinese (Tai Wan)
  ],
};

/** 语言列表（locale list） */
export const localeList: DropMenu[] = [
  //{
  //  // 阿拉伯语 Arabic
  //  icon: 'emojione:flag-for-united-arab-emirates',
  //  text: 'لغة عربية',
  //  event: LOCALE.AR_AE,
  //},
  //{
  //  // 阿塞拜疆语 Azerbaijani
  //  icon: 'emojione:flag-for-azerbaijan',
  //  text: 'Azərbaycan dili',
  //  event: LOCALE.AZ_AZ,
  //},
  //{
  //  // 保加利亚语 Bulgarian
  //  icon: 'emojione:flag-for-bulgaria',
  //  text: 'Български език',
  //  event: LOCALE.BG_BG,
  //},
  //{
  //  // 孟加拉语 Bengali
  //  icon: 'emojione:flag-for-bangladesh',
  //  text: 'বাংলা',
  //  event: LOCALE.BN_BD,
  //},
  //{
  //  // 加泰罗尼亚语 Catalan
  //  icon: 'openmoji:catalonia-flag',
  //  text: 'Català',
  //  event: LOCALE.CA_CA,
  //},
  //{
  //  // 捷克语 Czech
  //  icon: 'emojione:flag-for-czechia',
  //  text: 'Česko',
  //  event: LOCALE.CS_CZ,
  //},
  //{
  //  // 威尔士语 Welsh
  //  icon: 'emojione:flag-for-united-kingdom',
  //  text: 'Cymru',
  //  event: LOCALE.CY_GB,
  //},
  //{
  //  // 丹麦语（丹麦）Danish (Denmark)
  //  icon: 'emojione:flag-for-denmark',
  //  text: 'Dansk',
  //  event: LOCALE.DA_DK,
  //},
  //{
  //  // 德语 German
  //  icon: 'emojione:flag-for-germany',
  //  text: 'Deutsch',
  //  event: LOCALE.DE_DE,
  //},
  //{
  //  // 迪维希语 Dhivehi
  //  icon: 'emojione:flag-for-maldives',
  //  text: 'ދިވެހިބަސް',
  //  event: LOCALE.DV_DV,
  //},
  //{
  //  // 希腊语 Greek
  //  icon: 'emojione:flag-for-greece',
  //  text: 'Ελληνικά',
  //  event: LOCALE.EL_GR,
  //},
  {
    // 英语（美国）English (United States)
    icon: 'emojione:flag-for-united-states',
    text: 'English',
    event: LOCALE.EN_US,
  },
  //{
  //  // 英语（英国）English (United Kingdom)
  //  icon: 'emojione:flag-for-united-kingdom',
  //  text: 'English (Britain)',
  //  event: LOCALE.EN_GB,
  //},
  //{
  //  // 西班牙语 Spanish
  //  icon: 'emojione:flag-for-spain',
  //  text: 'Español',
  //  event: LOCALE.ES_ES,
  //},
  //{
  //  // 爱沙尼亚语 Estonian
  //  icon: 'emojione:flag-for-estonia',
  //  text: 'Eesti keel',
  //  event: LOCALE.ET_EE,
  //},
  //{
  //  // 巴斯克语 Basque
  //  icon: 'openmoji:basque-flag',
  //  text: 'Euskera',
  //  event: LOCALE.EU_ES,
  //},
  //{
  //  // 波斯语 Persian
  //  icon: 'emojione:flag-for-iran',
  //  text: 'فارسی',
  //  event: LOCALE.FA_IR,
  //},
  //{
  //  // 芬兰语（芬兰）Finnish (Finland)
  //  icon: 'emojione:flag-for-finland',
  //  text: 'Suomi',
  //  event: LOCALE.FI_FI,
  //},
  //{
  //  // 法语 French
  //  icon: 'emojione:flag-for-france',
  //  text: 'Français',
  //  event: LOCALE.FR_FR,
  //},
  //{
  //  // 爱尔兰语 Irish
  //  icon: 'emojione:flag-for-ireland',
  //  text: 'Gaeilgenah Éireann',
  //  event: LOCALE.GA_IE,
  //},
  //{
  //  // 加利西亚语 Galician
  //  icon: 'emojione:flag-for-spain',
  //  text: 'Galego',
  //  event: LOCALE.GL_ES,
  //},
  //{
  //  // 希伯来语（以色列）Hebrew (Israel)
  //  icon: 'emojione:flag-for-israel',
  //  text: 'Hebrew (Israel)',
  //  event: LOCALE.HE_IL,
  //},
  //{
  //  // 印地语 Hindi
  //  icon: 'emojione:flag-for-india',
  //  text: 'हिन्दी',
  //  event: LOCALE.HI_IN,
  //},
  //{
  //  // 克罗地亚语 Croatian
  //  icon: 'emojione:flag-for-croatia',
  //  text: 'Hrvatski',
  //  event: LOCALE.HR_HR,
  //},
  //{
  //  // 匈牙利语 Hungarian
  //  icon: 'emojione:flag-for-hungary',
  //  text: 'Magyar',
  //  event: LOCALE.HU_HU,
  //},
  //{
  //  // 亚美尼亚语 Armenian
  //  icon: 'emojione:flag-for-armenia',
  //  text: 'Հայերեն',
  //  event: LOCALE.HY_AM,
  //},
  //{
  //  // 印度尼西亚语 Indonesian
  //  icon: 'emojione:flag-for-indonesia',
  //  text: 'Bahasa Indonesia',
  //  event: LOCALE.ID_ID,
  //},
  //{
  //  // 冰岛语 Icelandic
  //  icon: 'emojione:flag-for-iceland',
  //  text: 'íslenska',
  //  event: LOCALE.IS_IS,
  //},
  //{
  //  // 意大利语 Italian
  //  icon: 'emojione:flag-for-italy',
  //  text: 'Italiano',
  //  event: LOCALE.IT_IT,
  //},
  {
    // 日语 Japanese
    icon: 'emojione:flag-for-japan',
    text: '日本語',
    event: LOCALE.JA_JP,
  },
  //{
  //  // 卡拜尔语 Kabyle
  //  icon: 'emojione:flag-for-algeria',
  //  text: 'Taqbaylit',
  //  event: LOCALE.KAB_DZ,
  //},
  //{
  //  // 哈萨克语 Kazakh
  //  icon: 'emojione:flag-for-kazakhstan',
  //  text: 'Қазақ тілі',
  //  event: LOCALE.KK_KZ,
  //},
  //{
  //  // 朝鲜语（南韩）Korean
  //  icon: 'emojione:flag-for-north-korea',
  //  text: '한국어.',
  //  event: LOCALE.KO_KR,
  //},
  //{
  //  // 库尔德语 Kurdish
  //  icon: 'emojione:flag-for-iran',
  //  text: 'کوردیی ناوەندی',
  //  event: LOCALE.CKB_IR,
  //},
  //{
  //  // 立陶宛语 Lithuanian
  //  icon: 'emojione:flag-for-lithuania',
  //  text: 'lietuvių kalba',
  //  event: LOCALE.LT_LT,
  //},
  //{
  //  // 拉脱维亚语 Latvian
  //  icon: 'emojione:flag-for-latvia',
  //  text: 'latviešu valoda',
  //  event: LOCALE.LV_LV,
  //},
  //{
  //  // 挪威博克马尔语 Norwegian Bokmal
  //  icon: 'emojione:flag-for-norway',
  //  text: 'Bokmål',
  //  event: LOCALE.NB_NB,
  //},
  //{
  //  // 挪威语（挪威）Norwegian (Norway)
  //  icon: 'emojione:flag-for-norway',
  //  text: 'Norwegian',
  //  event: LOCALE.NB_NO,
  //},
  //{
  //  // 尼泊尔语 Nepali
  //  icon: 'emojione:flag-for-nepal',
  //  text: 'नेपाली',
  //  event: LOCALE.NE_NP,
  //},
  //{
  //  // 荷兰语（荷兰）Dutch (Netherlands)
  //  icon: 'emojione:flag-for-caribbean-netherlands',
  //  text: 'Nederlands',
  //  event: LOCALE.NL_NL,
  //},
  //{
  //  // 荷兰语（比利时）Dutch (Belgium)
  //  icon: 'emojione:flag-for-belgium',
  //  text: 'Nederlands België',
  //  event: LOCALE.NL_BE,
  //},
  //{
  //  // 奥克语 Occitan
  //  icon: 'emojione:flag-for-france',
  //  text: 'Lenga d'òc',
  //  event: LOCALE.OC_OC,
  //},
  //{
  //  // 波兰语 Polish
  //  icon: 'emojione:flag-for-poland',
  //  text: 'Polski',
  //  event: LOCALE.PL_PL,
  //},
  //{
  //  // 葡萄牙语 Portuguese
  //  icon: 'emojione:flag-for-portugal',
  //  text: 'Português',
  //  event: LOCALE.PT_PT,
  //},
  //{
  //  // 葡萄牙语（巴西）Portuguese (Brazil)
  //  icon: 'emojione:flag-for-brazil',
  //  text: 'Português (Brasil)',
  //  event: LOCALE.PT_BR,
  //},
  //{
  //  // 罗马尼亚语 Romanian
  //  icon: 'emojione:flag-for-romania',
  //  text: 'limba română',
  //  event: LOCALE.RO_RO,
  //},
  //{
  //  // 俄语 Russian
  //  icon: 'emojione:flag-for-russia',
  //  text: 'русский язык',
  //  event: LOCALE.RU_RU,
  //},
  //{
  //  // 斯洛伐克语 Slovak
  //  icon: 'emojione:flag-for-slovakia',
  //  text: 'Slovenská',
  //  event: LOCALE.SK_SK,
  //},
  //{
  //  // 斯洛文尼亚语 Slovenian
  //  icon: 'emojione:flag-for-slovenia',
  //  text: 'slovenski jezik',
  //  event: LOCALE.SL_SL,
  //},
  //{
  //  // 阿尔巴尼亚语 Albanian
  //  icon: 'emojione:flag-for-albania',
  //  text: 'albanian',
  //  event: LOCALE.SQ_AL,
  //},
  //{
  //  // 塞尔维亚语（西里尔文） Serbian
  //  icon: 'emojione:flag-for-serbia',
  //  text: 'Cрпски',
  //  event: LOCALE.SR_CYRL_RS,
  //},
  //{
  //  // 瑞典语 Swedish
  //  icon: 'emojione:flag-for-sweden',
  //  text: 'Svenska',
  //  event: LOCALE.SV_SE,
  //},
  //{
  //  // 泰米尔语 Tamil
  //  icon: 'emojione:flag-for-india',
  //  text: 'தமிழ்',
  //  event: LOCALE.TA_IN,
  //},
  //{
  //  // 塔吉克语 Tajik
  //  icon: 'emojione:flag-for-tajikistan',
  //  text: 'Точики',
  //  event: LOCALE.TG_TJ,
  //},
  //{
  //  // 泰语 Thai
  //  icon: 'emojione:flag-for-thailand',
  //  text: 'ภาษาไทย',
  //  event: LOCALE.TH_TH,
  //},
  //{
  //  // 土耳其语 Turkish
  //  icon: 'emojione:flag-for-turkey',
  //  text: 'Türkçe',
  //  event: LOCALE.TR_TR,
  //},
  //{
  //  // 维吾尔语 Uyghur
  //  icon: 'emojione:flag-for-china',
  //  text: 'ئۇيغۇر تىلى',
  //  event: LOCALE.UG_CN,
  //},
  //{
  //  // 乌克兰语 Ukrainian
  //  icon: 'emojione:flag-for-ukraine',
  //  text: 'Українська Мова',
  //  event: LOCALE.UK_UK,
  //},
  //{
  //  // 越南语 Vietnamese
  //  icon: 'emojione:flag-for-vietnam',
  //  text: 'Việt',
  //  event: LOCALE.VI_VN,
  //},
  {
    // 简体中文 Chinese
    icon: 'emojione:flag-for-china',
    text: '简体中文',
    event: LOCALE.ZH_CN,
  },
  {
    // 繁体中文（台湾）Traditional Chinese (Tai Wan)
    icon: 'emojione:flag-for-taiwan',
    text: '繁體中文',
    event: LOCALE.ZH_TW,
  },
];
