import type { LockInfo } from '/#/store';

import { defineStore } from 'pinia';

import { LOCK_INFO_KEY } from '/@/enums/cacheEnum';
import { Persistent } from '/@/utils/cache/persistent';
import { useIdentityStore } from './identity';

interface LockState {
  lockInfo: Nullable<LockInfo>;
}

export const useLockStore = defineStore({
  id: 'app-lock',
  state: (): LockState => ({
    lockInfo: Persistent.getLocal(LOCK_INFO_KEY),
  }),
  getters: {
    getLockInfo(state): Nullable<LockInfo> {
      return state.lockInfo;
    },
  },
  actions: {
    setLockInfo(info: LockInfo) {
      this.lockInfo = Object.assign({}, this.lockInfo, info);
      Persistent.setLocal(LOCK_INFO_KEY, this.lockInfo, true);
    },
    resetLockInfo() {
      Persistent.removeLocal(LOCK_INFO_KEY, true);
      this.lockInfo = null;
    },
    /** 解锁（Unlock） */
    async unLock(password?: string) {
      const identityStore = useIdentityStore();
      if (this.lockInfo?.pwd === password) {
        this.resetLockInfo();
        return { Succeeded: true, Message: '' };
      }
      const tryLogin = async () => {
        const username = identityStore.getUserInfo?.UserName;
        const res = await identityStore.checkLogin({
          Account: username,
          Password: password!,
          goHome: false,
          mode: 'none',
        });
        if (res.Succeeded) {
          this.resetLockInfo();
        }
        return { Succeeded: res.Succeeded ?? false, Message: res.Content };
      };
      return await tryLogin();
    },
  },
});
