import { getOperateTypeEnumSchema } from '/@/enums/operateTypeEnum';
import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const operateTypeEnumSchema = getOperateTypeEnumSchema();

export const auditEntityColumns: AdColumn[] = [
  {
    title: t('routes.system.audit.auditEntityIdTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.audit.auditEntityNameTitle'),
    dataIndex: 'Name',
    width: 200,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityTypeNameTitle'),
    dataIndex: 'TypeName',
    width: 200,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityEntityKeyTitle'),
    dataIndex: 'EntityKey',
    width: 150,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityOperateTypeTitle'),
    dataIndex: 'OperateType',
    width: 200,
    filterable: true,
    dataType: 'enum',
    enumData: operateTypeEnumSchema,
  },
  {
    title: t('routes.system.audit.auditEntityUserIdTitle'),
    dataIndex: 'UserId',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Operation.UserId',
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityUserNameTitle'),
    dataIndex: 'UserName',
    width: 100,
    filterable: true,
    filterIndex: 'Operation.UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityUserNicknameTitle'),
    dataIndex: 'UserNickname',
    width: 100,
    filterable: true,
    filterIndex: 'Operation.UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityFunctionNameTitle'),
    dataIndex: 'FunctionName',
    width: 200,
    filterable: true,
    filterIndex: 'Operation.FunctionName',
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityCreatedTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    filterable: true,
    filterIndex: 'Operation.CreatedTime',
    dataType: 'datetime',
  },
];

export const auditPropertyColumns: AdColumn[] = [
  {
    title: t('routes.system.audit.auditEntityPropertieDisplayNameTitle'),
    dataIndex: 'DisplayName',
    width: 150,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityPropertieFieldNameTitle'),
    dataIndex: 'FieldName',
    width: 150,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityPropertieOriginalValueTitle'),
    dataIndex: 'OriginalValue',
    width: 200,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityPropertieNewValueTitle'),
    dataIndex: 'NewValue',
    width: 200,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditEntityPropertieDataTypeTitle'),
    dataIndex: 'DataType',
    width: 100,
    dataType: 'string',
  },
];
