import { getAjaxResultTypeEnumSchema } from '/@/enums/ajaxResultTypeEnum';
import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const ajaxResultTypeEnumSchema = getAjaxResultTypeEnumSchema();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.audit.auditOperation.functionNameTitle'),
    dataIndex: 'FunctionName',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.userIdTitle'),
    dataIndex: 'UserId',
    width: 200,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.userNameTitle'),
    dataIndex: 'UserName',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.userNicknameTitle'),
    dataIndex: 'UserNickname',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.ipTitle'),
    dataIndex: 'Ip',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.operationSystemTitle'),
    dataIndex: 'OperationSystem',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.browserTitle'),
    dataIndex: 'Browser',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.methodTitle'),
    dataIndex: 'Method',
    width: 75,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.contentTypeTitle'),
    dataIndex: 'ContentType',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.audit.auditOperation.queryStringTitle'),
    dataIndex: 'QueryString',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.audit.auditOperation.argumentsTitle'),
    dataIndex: 'Arguments',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.audit.auditOperation.messageTitle'),
    dataIndex: 'Message',
    width: 400,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.audit.auditOperation.resultDataTitle'),
    dataIndex: 'ResultData',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.audit.auditOperation.resultTypeTitle'),
    dataIndex: 'ResultType',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'enum',
    enumData: ajaxResultTypeEnumSchema,
  },
  {
    title: t('routes.system.audit.auditOperation.elapsedTitle'),
    dataIndex: 'Elapsed',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'number',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
];
