import { readUserNodes } from '/@/api/identity/admin/user';
import { readEntityInfoNodes } from '/@/api/authorization/admin/entityinfo';
import { getDataAuthOperationEnumSchema } from '/@/enums/dataAuthOperationEnum';
import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const dataAuthOperationEnumSchema = getDataAuthOperationEnumSchema();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.authorization.userEntity.userIdTitle'),
    dataIndex: 'UserId',
    width: 200,
    defaultHidden: true,
    formVisible: true,
    formEditable: true,
    filterable: true,
    required: true,
    dataType: 'integer',
    editComponent: 'ApiSelect',
    editComponentProps: {
      api: readUserNodes,
      // use name as label
      labelField: 'UserName',
      // use id as value
      valueField: 'Id',
      showSearch: true,
      optionFilterProp: 'UserName',
      // not request untill to select
      immediate: true,
    },
  },
  {
    title: t('routes.system.authorization.userEntity.userNameTitle'),
    dataIndex: 'UserName',
    width: 200,
    formVisible: false,
    formEditable: false,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.userEntity.userNicknameTitle'),
    dataIndex: 'UserNickname',
    width: 200,
    formVisible: false,
    formEditable: false,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.userEntity.entityIdTitle'),
    dataIndex: 'EntityId',
    width: 300,
    defaultHidden: true,
    formVisible: true,
    formEditable: true,
    filterable: true,
    required: true,
    dataType: 'integer',
    editComponent: 'ApiSelect',
    editComponentProps: {
      api: readEntityInfoNodes,
      // use name as label
      labelField: 'Name',
      // use id as value
      valueField: 'Id',
      showSearch: true,
      optionFilterProp: 'Name',
      // not request untill to select
      immediate: true,
    },
  },
  {
    title: t('routes.system.authorization.userEntity.entityNameTitle'),
    dataIndex: 'EntityName',
    width: 300,
    formVisible: false,
    formEditable: false,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.userEntity.entityTypeTitle'),
    dataIndex: 'EntityType',
    width: 360,
    formVisible: false,
    formEditable: false,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.userEntity.operationTitle'),
    dataIndex: 'Operation',
    width: 100,
    formVisible: true,
    formEditable: true,
    filterable: true,
    required: true,
    dataType: 'enum',
    enumData: dataAuthOperationEnumSchema,
  },
  {
    title: t('entity.lockable.isLockedTitle'),
    dataIndex: 'IsLocked',
    width: 75,
    formVisible: true,
    formEditable: true,
    filterable: true,
    required: true,
    dataType: 'boolean',
    formCustomer: {
      colProps: {
        // span: 12,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 12, // ≥1200px
        xxl: 12, // ≥1600px
        // xxxl: 12, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    filterable: true,
    formVisible: true,
    formEditable: false,
    dataType: 'datetime',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    filterable: true,
    formVisible: true,
    formEditable: false,
    dataType: 'datetime',
  },
  {
    title: t('entity.dataVersion.dataVersionTitle'),
    dataIndex: 'DataVersion',
    width: 200,
    filterable: true,
    formVisible: true,
    formEditable: false,
    dataType: 'integer',
  },
];
