import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';
import { DictInputDto, DictOutputDto, DictEntryInputDto, DictEntryOutputDto } from './dict.data';

//#region 字典项
enum DictApi {
  ReadDict = '/api/admin/dict/readdict',
  CreateDict = '/api/admin/dict/createdict',
  UpdateDict = '/api/admin/dict/updatedict',
  DeleteDict = '/api/admin/dict/deletedict',
  ReadDictEntry = '/api/admin/dict/readdictentry',
  CreateDictEntry = '/api/admin/dict/createdictentry',
  UpdateDictEntry = '/api/admin/dict/updatedictentry',
  DeleteDictEntry = '/api/admin/dict/deletedictentry'
}

export function ReadDict(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<DictOutputDto>>(
    {
      url: DictApi.ReadDict,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function CreateDict(dtos: DictInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.CreateDict,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function UpdateDict(dtos: DictInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.UpdateDict,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function DeleteDict(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.DeleteDict,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

//#endregion

//#region 字典值
export function ReadDictEntry(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<DictEntryOutputDto>>(
    {
      url: DictApi.ReadDictEntry,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function CreateDictEntry(dtos: DictEntryInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.CreateDictEntry,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function UpdateDictEntry(dtos: DictEntryInputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.UpdateDictEntry,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function DeleteDictEntry(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: DictApi.DeleteDictEntry,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

//#endregion