import { getOrganizationTypeEnumSchema } from '/@/enums/organizationTypeEnum';
import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';

const organizationTypeEnumSchema = getOrganizationTypeEnumSchema();

const { t } = useI18n();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: false,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
    //align: 'left',
  },
  {
    title: t('routes.system.identity.organization.nameTitle'),
    dataIndex: 'Name',
    width: 300,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.typeTitle'),
    dataIndex: 'Type',
    width: 75,
    filterable: true,
    dataType: 'enum',
    enumData: organizationTypeEnumSchema,
  },
  {
    title: t('routes.system.identity.organization.descriptionTitle'),
    dataIndex: 'Description',
    width: 300,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.nameFrgnTitle'),
    dataIndex: 'NameFrgn',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.NameFrgn',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.addressTitle'),
    dataIndex: 'Address',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.Address',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.addressFrgnTitle'),
    dataIndex: 'AddressFrgn',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.AddressFrgn',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.printHeaderTitle'),
    dataIndex: 'PrintHeader',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.PrintHeader',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.printHeaderFrgnTitle'),
    dataIndex: 'PrintHeaderFrgn',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.PrintHeaderFrgn',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.reptNameTitle'),
    dataIndex: 'ReptName',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.ReptName',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.reptNameFrgnTitle'),
    dataIndex: 'ReptNameFrgn',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.ReptNameFrgn',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.organization.remarkTitle'),
    dataIndex: 'Remark',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'Detail.Remark',
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.organization.orderNumberTitle'),
    dataIndex: 'OrderNumber',
    width: 75,
    filterable: false,
    dataType: 'number',
  },
  {
    title: t('routes.system.identity.organization.treePathStringTitle'),
    dataIndex: 'TreePathString',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.organization.parentIdTitle'),
    dataIndex: 'ParentId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.identity.organization.enableLoginTitle'),
    dataIndex: 'EnableLogin',
    width: 75,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.identity.organization.isDefaultTitle'),
    dataIndex: 'IsDefault',
    width: 75,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.identity.organization.isSystemTitle'),
    dataIndex: 'IsSystem',
    width: 75,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('entity.lockable.isLockedTitle'),
    dataIndex: 'IsLocked',
    width: 75,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.identity.organization.levelTitle'),
    dataIndex: 'Level',
    width: 50,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorNameTitle'),
    dataIndex: 'CreatorName',
    width: 0,
    ifShow: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorNicknameTitle'),
    dataIndex: 'CreatorNickname',
    width: 0,
    ifShow: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.updateAudited.updaterIdTitle'),
    dataIndex: 'UpdaterId',
    width: 0,
    ifShow: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.updateAudited.updaterNameTitle'),
    dataIndex: 'UpdaterName',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updaterNicknameTitle'),
    dataIndex: 'UpdaterNickname',
    width: 0,
    ifShow: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
];
