import { getAccessTypeEnumSchema } from '/@/enums/accessTypeEnum';
import { AdColumn } from '/@/components/AdTable';
import { TreeItem } from '/@/components/Tree';
import { useI18n } from '/@/hooks/web/useI18n';

const accessTypeEnumSchema = getAccessTypeEnumSchema();
const { t } = useI18n();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    edit: false,
    editRow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.identity.role.nameTitle'),
    dataIndex: 'Name',
    width: 150,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    dataType: 'string',
    sorter: { multiple: 1 },
  },
  {
    title: t('routes.system.identity.role.descriptionTitle'),
    dataIndex: 'Description',
    width: 200,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'string',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.identity.role.remarkTitle'),
    dataIndex: 'Remark',
    width: 200,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.identity.role.isAdminTitle'),
    dataIndex: 'IsAdmin',
    width: 70,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    sorter: { multiple: 2 },
    formCustomer: {
      colProps: {
        // span: 8,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 12, // ≥768px
        lg: 12, // ≥992px
        xl: 8, // ≥1200px
        xxl: 8, // ≥1600px
        // xxxl: 8, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.identity.role.isDefaultTitle'),
    dataIndex: 'IsDefault',
    width: 65,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    sorter: { multiple: 3 },
    formCustomer: {
      colProps: {
        // span: 8,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 12, // ≥768px
        lg: 12, // ≥992px
        xl: 8, // ≥1200px
        xxl: 8, // ≥1600px
        // xxxl: 8, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('entity.lockable.isLockedTitle'),
    dataIndex: 'IsLocked',
    width: 65,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    sorter: { multiple: 4 },
    formCustomer: {
      colProps: {
        // span: 8,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 12, // ≥768px
        lg: 12, // ≥992px
        xl: 8, // ≥1200px
        xxl: 8, // ≥1600px
        // xxxl: 8, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorNameTitle'),
    dataIndex: 'CreatorName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorNicknameTitle'),
    dataIndex: 'CreatorNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    edit: false,
    editRow: false,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
    sorter: { multiple: 5 },
  },
  {
    title: t('entity.updateAudited.updaterIdTitle'),
    dataIndex: 'UpdaterId',
    width: 0,
    ifShow: false,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.updateAudited.updaterNameTitle'),
    dataIndex: 'UpdaterName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updaterNicknameTitle'),
    dataIndex: 'UpdaterNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
    sorter: { multiple: 6 },
  },
];

export const roleFunctionColumns: AdColumn[] = [
  {
    title: t('routes.system.authorization.functionIdTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.authorization.functionNameTitle'),
    dataIndex: 'Name',
    width: 300,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.functionAccessTypeTitle'),
    dataIndex: 'AccessType',
    width: 100,
    filterable: true,
    dataType: 'enum',
    enumData: accessTypeEnumSchema,
  },
  {
    title: t('routes.system.authorization.functionAreaTitle'),
    dataIndex: 'Area',
    width: 150,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.functionControllerTitle'),
    dataIndex: 'Controller',
    width: 200,
    filterable: true,
    dataType: 'string',
  },
];

/**
 * 将原始树数据节点转换为 `TreeItem`节点
 * @param nodes 原始树数据节点
 * @param checkedKeys 选中值
 */
export function makeRoleModulesTree(nodes: any[], checkedKeys: (string | bigint)[]): TreeItem[] {
  if (!nodes.length) {
    return [];
  }
  const result: TreeItem[] = [];
  for (const node of nodes) {
    const hasAuth = node.HasChildren ? false : node.HasAuth;
    const icon = node.HasChildren
      ? 'ri:shield-check-line'
      : node.HasAuth
      ? 'emojione-v1:white-heavy-check-mark'
      : 'noto-v1:check-mark-button';
    const title = `${node.FullName.replace('根节点-', '')}${hasAuth ? '(已授权)' : ''} --> ${
      node.Code
    }`;
    const item: TreeItem = {
      icon: icon,
      key: node.Id,
      title: title,
      checked: node.IsChecked,
      isLeaf: !node.HasChildren,
    };
    if (node.IsChecked) {
      checkedKeys.push(node.Id);
    }
    if (node.Children && node.Children.length > 0) {
      item.children = makeRoleModulesTree(node.Children, checkedKeys);
    }
    result.push(item);
  }
  return result;
}
