import { expandAndToString } from '/@/utils/common';
import { AdColumn } from '/@/components/AdTable';
import { TreeItem } from '/@/components/Tree/index';

import { getAccessTypeEnumSchema } from '/@/enums/accessTypeEnum';
import { getGenderEnumSchema } from '/@/enums/genderEnum';
import { getChineseZodiacSignEnumSchema } from '/@/enums/chineseZodiacSignEnum';
import { getStarSignEnumSchema } from '/@/enums/starSignEnum';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();
const genderEnumSchema = getGenderEnumSchema();
const zodiacSignEnumSchema = getChineseZodiacSignEnumSchema();
const starSignEnumSchema = getStarSignEnumSchema();
const accessTypeEnumSchema = getAccessTypeEnumSchema();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.identity.user.userNameTitle'),
    dataIndex: 'UserName',
    width: 120,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    dataType: 'string',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.nickNameTitle'),
    dataIndex: 'NickName',
    width: 200,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    dataType: 'string',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.passwordTitle'),
    dataIndex: 'Password',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: true,
    filterable: false,
    dataType: 'password',
  },
  {
    title: t('routes.system.identity.user.emailTitle'),
    dataIndex: 'Email',
    width: 180,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'email',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.emailConfirmedTitle'),
    dataIndex: 'EmailConfirmed',
    width: 95,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.phoneNumberTitle'),
    dataIndex: 'PhoneNumber',
    width: 100,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'mobile',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.phoneConfirmedTitle'),
    dataIndex: 'PhoneConfirmed',
    width: 95,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.genderTitle'),
    dataIndex: 'Gender',
    width: 65,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    filterIndex: 'Detail.Gender',
    dataType: 'enum',
    enumData: genderEnumSchema,
    sorter: true,
  },
  {
    title: t('routes.system.identity.user.birthdayTitle'),
    dataIndex: 'Birthday',
    width: 120,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.Birthday',
    dataType: 'date',
  },
  {
    title: t('routes.system.identity.user.bloodTypeTitle'),
    dataIndex: 'BloodType',
    width: 100,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.BloodType',
    dataType: 'string',
  },
  {
    title: t('routes.system.identity.user.tagTitle'),
    dataIndex: 'Tag',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterIndex: 'Detail.Tag',
    dataType: 'array',
  },
  {
    title: t('routes.system.identity.user.userTitleTitle'),
    dataIndex: 'Title',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterIndex: 'Detail.Title',
    dataType: 'array',
  },
  {
    title: t('routes.system.identity.user.addressTitle'),
    dataIndex: 'Address',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.Address',
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.user.profileTitle'),
    dataIndex: 'Profile',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.Profile',
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.user.signatureTitle'),
    dataIndex: 'Sign',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.Sign',
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.user.chineseBirthdayTitle'),
    dataIndex: 'ChineseBirthday',
    width: 120,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'date',
  },
  {
    title: t('routes.system.identity.user.ageTitle'),
    dataIndex: 'Age',
    width: 45,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.identity.user.zodiacSignTitle'),
    dataIndex: 'ZodiacSign',
    width: 45,
    formVisible: false,
    filterable: false,
    dataType: 'enum',
    enumData: zodiacSignEnumSchema,
  },
  {
    title: t('routes.system.identity.user.starSignTitle'),
    dataIndex: 'StarSign',
    width: 75,
    formVisible: false,
    filterable: false,
    dataType: 'enum',
    enumData: starSignEnumSchema,
  },
  {
    title: t('routes.system.identity.user.remarkTitle'),
    dataIndex: 'Remark',
    width: 200,
    formVisible: true,
    formEditable: true,
    filterable: true,
    filterIndex: 'Detail.Remark',
    dataType: 'text',
  },
  {
    title: t('routes.system.identity.user.rolesTitle'),
    dataIndex: 'Roles',
    width: 200,
    formVisible: false,
    formEditable: false,
    filterable: false,
    dataType: 'array',
    format: (_text: string, record: Recordable, _index: number) => {
      return expandAndToString(record.Roles);
    },
  },
  {
    title: t('entity.lockable.isLockedTitle'),
    dataIndex: 'IsLocked',
    width: 75,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.identity.user.lockoutEnabledTitle'),
    dataIndex: 'LockoutEnabled',
    width: 90,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.identity.user.accessFailedCountTitle'),
    dataIndex: 'AccessFailedCount',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.identity.user.lockoutEndTitle'),
    dataIndex: 'LockoutEnd',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
];

export const userFunctionColumns: AdColumn[] = [
  {
    title: t('routes.system.authorization.functionIdTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.authorization.functionNameTitle'),
    dataIndex: 'Name',
    width: 300,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.functionAccessTypeTitle'),
    dataIndex: 'AccessType',
    width: 100,
    filterable: true,
    dataType: 'enum',
    enumData: accessTypeEnumSchema,
  },
  {
    title: t('routes.system.authorization.functionAreaTitle'),
    dataIndex: 'Area',
    width: 150,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.authorization.functionControllerTitle'),
    dataIndex: 'Controller',
    width: 200,
    filterable: true,
    dataType: 'string',
  },
];

/** 树形数据项 */
export interface TreeDataItem extends TreeItem {
  description: string;
  children?: TreeDataItem[];
}
/**
 * 将原始树数据节点转换为 `TreeItem`节点
 * @param nodes 原始树数据节点
 * @param checkedKeys 选中值
 */
export function makeUserModulesTree(nodes: any[], checkedKeys: string[]): TreeDataItem[] {
  if (!nodes.length) {
    return [];
  }
  const result: TreeDataItem[] = [];
  for (const node of nodes) {
    const hasAuth = node.HasChildren ? false : node.HasAuth;
    const icon = node.HasChildren
      ? 'ri:shield-check-line'
      : node.HasAuth
      ? 'emojione-v1:white-heavy-check-mark'
      : 'noto-v1:check-mark-button';
    const title = `${node.FullName.replace('根节点-', '')}${hasAuth ? '(已授权)' : ''} --> ${
      node.Code
    }`;
    const item: TreeDataItem = {
      icon: icon,
      key: node.Id as string,
      title: title,
      checked: node.IsChecked as boolean,
      description: node.Name as string,
      isLeaf: !node.HasChildren,
    };
    if (node.IsChecked) {
      checkedKeys.push(node.Id);
    }
    if (node.Children && node.Children.length > 0) {
      item.children = makeUserModulesTree(node.Children, checkedKeys);
    }
    result.push(item);
  }
  return result;
}
