import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';
import { getMessageTypeEnumSchema } from '/@/enums/messageTypeEnum';
import { getMessageLevelEnumSchema } from '/@/enums/messageLevelEnum';
import { getMessageSendWayEnumSchema } from '/@/enums/messageSendWayEnum';

const { t } = useI18n();
const messageTypeEnumSchema = getMessageTypeEnumSchema();
const messageLevelEnumSchema = getMessageLevelEnumSchema();
const messageSendWayEnumSchema = getMessageSendWayEnumSchema();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 150,
    filterable: true,
    filterIndex: 'Id',
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.message.baseTypeText'),
    dataIndex: 'BaseType',
    width: 150,
    filterable: true,
    filterIndex: 'BaseType',
    dataType: 'string',
  },
  {
    title: t('routes.system.message.message.baseIdText'),
    dataIndex: 'BaseId',
    width: 150,
    filterable: true,
    filterIndex: 'BaseId',
    dataType: 'string',
  },
  {
    title: t('routes.system.message.methodText'),
    dataIndex: 'Method',
    width: 100,
    filterable: true,
    filterIndex: 'Method',
    dataType: 'string',
  },
  {
    title: t('routes.system.message.iconText'),
    dataIndex: 'Icon',
    width: 60,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.message.messageTypeText'),
    dataIndex: 'MessageType',
    width: 90,
    filterable: true,
    dataType: 'enum',
    enumData: messageTypeEnumSchema,
  },
  {
    title: t('routes.system.message.messageLevelText'),
    dataIndex: 'MessageLevel',
    width: 90,
    filterable: true,
    dataType: 'enum',
    enumData: messageLevelEnumSchema,
  },
  {
    title: t('routes.system.message.titleText'),
    dataIndex: 'Title',
    width: 200,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.message.contentText'),
    dataIndex: 'Content',
    width: 300,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.message.payloadText'),
    dataIndex: 'Payload',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'string',
  },
  {
    title: t('routes.system.message.message.sendTimeText'),
    dataIndex: 'SendTime',
    width: 150,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('routes.system.message.sendWaysText'),
    dataIndex: 'SendWays',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.message.toUsersText'),
    dataIndex: 'ToUsers',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.message.toOrganizationsText'),
    dataIndex: 'ToOrganizations',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.message.toRolesText'),
    dataIndex: 'ToRoles',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.message.storageDaysText'),
    dataIndex: 'StorageDays',
    width: 80,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.message.isSystemText'),
    dataIndex: 'IsSystem',
    width: 80,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.message.message.senderIdText'),
    dataIndex: 'SenderId',
    width: 0,
    ifShow: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.message.senderNameText'),
    dataIndex: 'SenderName',
    width: 100,
    filterable: true,
    filterIndex: 'SenderId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.message.message.senderNicknameText'),
    dataIndex: 'SenderNickname',
    width: 100,
    filterable: true,
    filterIndex: 'SenderId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.message.message.isSentText'),
    dataIndex: 'IsSent',
    width: 80,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorNameTitle'),
    dataIndex: 'CreatorName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorNicknameTitle'),
    dataIndex: 'CreatorNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.updateAudited.updaterIdTitle'),
    dataIndex: 'UpdaterId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.updateAudited.updaterNameTitle'),
    dataIndex: 'UpdaterName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updaterNicknameTitle'),
    dataIndex: 'UpdaterNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
];

export const receiverColumns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 150,
    filterable: true,
    filterIndex: 'Id',
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.messageIdText'),
    dataIndex: 'MessageId',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.message.receiverIdText'),
    dataIndex: 'ReceiverId',
    width: 0,
    ifShow: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.message.message.receiverNameText'),
    dataIndex: 'ReceiverName',
    width: 100,
    filterable: true,
    filterIndex: 'ReceiverId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.message.message.receiverNicknameText'),
    dataIndex: 'ReceiverNickname',
    width: 100,
    filterable: true,
    filterIndex: 'ReceiverId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.message.sendWaysText'),
    dataIndex: 'SendWays',
    width: 0,
    ifShow: false,
    filterable: false,
    dataType: 'text',
  },
  {
    title: t('routes.system.message.message.lastReadTimeText'),
    dataIndex: 'LastReadTime',
    width: 150,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('routes.system.message.message.lastReadWayText'),
    dataIndex: 'LastReadWay',
    width: 90,
    filterable: true,
    dataType: 'enum',
    enumData: messageSendWayEnumSchema,
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    filterable: true,
    dataType: 'datetime',
  },
];
