import { h } from 'vue';
import { Input } from 'ant-design-vue';
import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';

const { t } = useI18n();

export const columns: AdColumn[] = [
  {
    title: t('entity.idTitle'),
    dataIndex: 'Id',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printLog.printIdTitle'),
    dataIndex: 'PrintId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Template.Print.Id',
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printLog.printCodeTitle'),
    dataIndex: 'PrintCode',
    width: 300,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Template.Print.PrintCode',
    dataType: 'string',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.report.print.printLog.printNameTitle'),
    dataIndex: 'PrintName',
    width: 300,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Print.Name',
    dataType: 'string',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('routes.system.report.print.printLog.templateIdTitle'),
    dataIndex: 'TemplateId',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printLog.templateNameTitle'),
    dataIndex: 'TemplateName',
    width: 300,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Template.TemplateName',
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printLog.keyTitle'),
    dataIndex: 'Key',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printLog.valueTitle'),
    dataIndex: 'Value',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printLog.argumentsTitle'),
    dataIndex: 'Arguments',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'text',
    formCustomer: {
      colProps: {
        // span: 24,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 24, // ≥768px
        lg: 24, // ≥992px
        xl: 24, // ≥1200px
        xxl: 24, // ≥1600px
        // xxxl: 24, // ≥2000px 3.0
      },
      render: ({ model, field }) => {
        return h(Input.TextArea, {
          value: JSON.stringify(model[field]),
          disabled: true,
        });
      },
    },
  },
  {
    title: t('routes.system.report.print.printLog.userIdTitle'),
    dataIndex: 'UserId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: false,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printLog.userNameTitle'),
    dataIndex: 'UserName',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printLog.userNicknameTitle'),
    dataIndex: 'UserNickname',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UserId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
];
