import { AdColumn } from '/@/components/AdTable';
import { useI18n } from '/@/hooks/web/useI18n';
import { getReportTypeEnumSchema } from '/@/enums/reportTypeEnum';

const { t } = useI18n();
const reportTypeEnumSchema = getReportTypeEnumSchema();

export const printColumns: AdColumn[] = [
  {
    title: t('routes.system.report.print.printSetup.printIdTitle'),
    dataIndex: 'Id',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Id',
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printSetup.printCodeTitle'),
    dataIndex: 'PrintCode',
    width: 260,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    filterIndex: 'PrintCode',
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printSetup.printNameTitle'),
    dataIndex: 'PrintName',
    width: 320,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    filterIndex: 'Name',
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printSetup.commentsTitle'),
    dataIndex: 'Comments',
    width: 300,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'text',
  },
  {
    title: t('routes.system.report.print.printSetup.logEnabledTitle'),
    dataIndex: 'LogEnabled',
    width: 100,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
    formCustomer: {
      colProps: {
        // span: 12,
        xs: 24, // <576px
        sm: 24, // ≥576px
        md: 12, // ≥768px
        lg: 12, // ≥992px
        xl: 12, // ≥1200px
        xxl: 12, // ≥1600px
        // xxxl: 6, // ≥2000px 3.0
      },
    },
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorNameTitle'),
    dataIndex: 'CreatorName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorNicknameTitle'),
    dataIndex: 'CreatorNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.updateAudited.updaterIdTitle'),
    dataIndex: 'UpdaterId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.updateAudited.updaterNameTitle'),
    dataIndex: 'UpdaterName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updaterNicknameTitle'),
    dataIndex: 'UpdaterNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.dataVersion.dataVersionTitle'),
    dataIndex: 'DataVersion',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'integer',
  },
];

export const templateColumns: AdColumn[] = [
  {
    title: t('routes.system.report.print.printSetup.templateIdTitle'),
    dataIndex: 'Id',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'Id',
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printSetup.printIdTitle'),
    dataIndex: 'PrintId',
    width: 0,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'integer',
  },
  {
    title: t('routes.system.report.print.printSetup.templateNameTitle'),
    dataIndex: 'TemplateName',
    width: 260,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'string',
  },
  {
    title: t('routes.system.report.print.printSetup.templateTypeTitle'),
    dataIndex: 'TemplateType',
    width: 90,
    formVisible: true,
    formEditable: true,
    required: true,
    filterable: true,
    dataType: 'enum',
    enumData: reportTypeEnumSchema,
  },
  {
    title: t('routes.system.report.print.printSetup.userAsgnTitle'),
    dataIndex: 'UserAsgn',
    width: 75,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.report.print.printSetup.orgAsgnTitle'),
    dataIndex: 'OrgAsgn',
    width: 75,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.report.print.printSetup.commentsTitle'),
    dataIndex: 'Comments',
    width: 300,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'text',
  },
  {
    title: t('routes.system.report.print.printSetup.logEnabledTitle'),
    dataIndex: 'LogEnabled',
    width: 100,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.report.print.printSetup.enabledTitle'),
    dataIndex: 'Enabled',
    width: 75,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'boolean',
  },
  {
    title: t('routes.system.report.print.printSetup.enableFromTitle'),
    dataIndex: 'EnableFrom',
    width: 120,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'date',
  },
  {
    title: t('routes.system.report.print.printSetup.enableToTitle'),
    dataIndex: 'EnableTo',
    width: 120,
    formVisible: true,
    formEditable: true,
    filterable: true,
    dataType: 'date',
  },
  {
    title: t('entity.creationAudited.creatorIdTitle'),
    dataIndex: 'CreatorId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.creationAudited.creatorNameTitle'),
    dataIndex: 'CreatorName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.creatorNicknameTitle'),
    dataIndex: 'CreatorNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'CreatorId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.creationAudited.createdTimeTitle'),
    dataIndex: 'CreatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.updateAudited.updaterIdTitle'),
    dataIndex: 'UpdaterId',
    width: 0,
    ifShow: false,
    defaultHidden: true,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'integer',
  },
  {
    title: t('entity.updateAudited.updaterNameTitle'),
    dataIndex: 'UpdaterName',
    width: 100,
    filterable: true,
    formVisible: true,
    formEditable: false,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'UserName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updaterNicknameTitle'),
    dataIndex: 'UpdaterNickname',
    width: 100,
    formVisible: true,
    formEditable: false,
    filterable: true,
    filterIndex: 'UpdaterId',
    filterJoin: {
      entityType: 'EaCloud.Pack.Identity.Core.Entities.User,EaCloud.Pack.Identity',
      filterField: 'NickName',
      selectField: 'Id',
    },
    dataType: 'string',
  },
  {
    title: t('entity.updateAudited.updatedTimeTitle'),
    dataIndex: 'UpdatedTime',
    width: 150,
    formVisible: true,
    formEditable: false,
    filterable: true,
    dataType: 'datetime',
  },
  {
    title: t('entity.dataVersion.dataVersionTitle'),
    dataIndex: 'DataVersion',
    width: 200,
    formVisible: true,
    formEditable: false,
    filterable: false,
    dataType: 'integer',
  },
];
