import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';
import { InputDto, OutputDto } from './ipn.data';

enum Api {
  Get = '/api/admin/ipn/get',
  Read = '/api/admin/ipn/read',
  Create = '/api/admin/ipn/create',
  Update = '/api/admin/ipn/update',
  Delete = '/api/admin/ipn/delete',
  GetMaterialTreeNodes = '/api/admin/materialcategory/gettreenodes',
  GetDictNodes = '/api/admin/ipn/getdicts',
  ReadTreeNode = '/api/admin/materialonelevel/readtreenode',
  ReadOneLevelNodes = '/api/admin/materialonelevel/readnodes',
  ApplyToRdSupervisor = '/api/admin/ipn/applytordsupervisor',
  ApplyToIpnSupervisor = '/api/admin/ipn/applytoipnsupervisor',
  Reject = '/api/admin/ipn/reject',
  Success = '/api/admin/ipn/success',
}

export function Get(ipnNo: string, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Get,
      params: { ipnNo },
    },
    {
      joinParamsToUrl: true,
      errorMessageMode: mode,
    },
  );
}

export function Read(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<OutputDto>>(
    {
      url: Api.Read,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Create(dtos: InputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Create,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Update(dtos: InputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Update,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Delete(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Delete,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function ApplyToRdSupervisor(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ApplyToRdSupervisor,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function ApplyToIpnSupervisor(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ApplyToIpnSupervisor,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Reject(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Reject,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Success(dtos: InputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Success,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function GetMaterialTreeNodes(mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.GetMaterialTreeNodes,
      params: {},
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function ReadOneLevelNodes(mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.ReadOneLevelNodes,
      params: {},
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function GetDictNodes(code: string, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.GetDictNodes,
      params: { code },
    },
    {
      joinParamsToUrl: true,
      errorMessageMode: mode,
    },
  );
}
