import { EnumSchema } from '/@/utils/common/types';
import { PresetColorEnum } from '/@/enums/colorEnum';

//#region 申请单状态
export enum StatusEnum {
  BeforeApply = 0,
  RdSupervisor,
  IpnSupervisor,
  AfterApply
}

export class StatusEntity {
  Type: StatusEnum;
  /** 显示描述 */
  Display: string;
  /** 颜色 */
  Color?: PresetColorEnum | string;

  constructor(status: StatusEnum, color?: PresetColorEnum | string) {
    this.Type = status;
    this.Color = color;
    switch (status) {
      case StatusEnum.BeforeApply:
        this.Display = '待申请';
        this.Color = this.Color ? this.Color : PresetColorEnum.Green;
        break;
      case StatusEnum.RdSupervisor:
        this.Display = '研发审批中';
        this.Color = this.Color ? this.Color : PresetColorEnum.Blue;
        break;
      case StatusEnum.IpnSupervisor:
        this.Display = 'IPN审批中';
        this.Color = this.Color ? this.Color : PresetColorEnum.Blue;
        break;
      case StatusEnum.AfterApply:
        this.Display = '申请结束';
        this.Color = this.Color ? this.Color : PresetColorEnum.Cyan;
        break;
    }
  }
}

export function getStatusSchema(enableTag = true): EnumSchema[] {
  const enumSchema: EnumSchema[] = [];
  const typeEntities: StatusEntity[] = [
    new StatusEntity(StatusEnum.BeforeApply),
    new StatusEntity(StatusEnum.RdSupervisor),
    new StatusEntity(StatusEnum.IpnSupervisor),
    new StatusEntity(StatusEnum.AfterApply)
  ];
  typeEntities.forEach((item) => {
    enumSchema.push({
      key: item.Type as number,
      label: item.Display,
      value: item.Type as number,
      tag: enableTag,
      tagColor: item.Color,
    });
  });
  return enumSchema;
}
//#endregion