import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';
import { InputDto, OutputDto } from './materialinstorage.data';

enum Api {
  Read = '/api/admin/materialinstorage/read',
  Create = '/api/admin/materialinstorage/create',
  Update = '/api/admin/materialinstorage/update',
  Delete = '/api/admin/materialinstorage/delete',
}

export function Read(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<OutputDto>>(
    {
      url: Api.Read,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Create(dto: InputDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Create,
      params: dto,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Update(dto: InputDto, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Update,
      params: dto,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Delete(id: string, mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Delete,
      params: { id },
    },
    {
      joinParamsToUrl: true,
      errorMessageMode: mode,
    },
  );
}
