import { EnumSchema } from '/@/utils/common/types';
import { PresetColorEnum } from '/@/enums/colorEnum';

//#region 是否已办理入库
export enum HandleStatusTypeEnum {
  No = 0,
  Yes,
}

export class HandleStatusTypeEntity {
  Type: HandleStatusTypeEnum;
  /** 显示描述 */
  Display: string;
  /** 颜色 */
  Color?: PresetColorEnum | string;

  constructor(handleStatusType: HandleStatusTypeEnum, color?: PresetColorEnum | string) {
    this.Type = handleStatusType;
    this.Color = color;
    switch (handleStatusType) {
      case HandleStatusTypeEnum.No:
        this.Display = '未办理';
        this.Color = this.Color ? this.Color : PresetColorEnum.Green;
        break;
      case HandleStatusTypeEnum.Yes:
        this.Display = '已办理';
        this.Color = this.Color ? this.Color : PresetColorEnum.Blue;
        break;
    }
  }
}

export function getHandleStatusTypeEnumSchema(enableTag = true): EnumSchema[] {
  const enumSchema: EnumSchema[] = [];
  const typeEntities: HandleStatusTypeEntity[] = [
    new HandleStatusTypeEntity(HandleStatusTypeEnum.No),
    new HandleStatusTypeEntity(HandleStatusTypeEnum.Yes),
  ];
  typeEntities.forEach((item) => {
    enumSchema.push({
      key: item.Type as number,
      label: item.Display,
      value: item.Type as number,
      tag: enableTag,
      tagColor: item.Color,
    });
  });
  return enumSchema;
}
//#endregion
