import { httpClient } from '/@/utils/http/axios';
import { ErrorMessageMode } from '/#/axios';
import { AjaxResult } from '/@/api/model';
import { PageRequest, PageData } from '/@/utils/common/types';
import { InputDto, OutputDto } from './warehouse.data';

enum Api {
  Read = '/api/admin/warehouse/read',
  Create = '/api/admin/warehouse/create',
  Update = '/api/admin/warehouse/update',
  Delete = '/api/admin/warehouse/delete',
  GetWareHouseTreeNodes = '/api/admin/warehouse/gettreenodes',
}

export function Read(request: PageRequest, mode: ErrorMessageMode = 'message') {
  return httpClient.post<PageData<OutputDto>>(
    {
      url: Api.Read,
      params: request,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Create(dtos: InputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Create,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Update(dtos: InputDto[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Update,
      params: dtos,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function Delete(ids: string[], mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.Delete,
      params: ids,
    },
    {
      errorMessageMode: mode,
    },
  );
}

export function GetWareHouseTreeNodes(mode: ErrorMessageMode = 'message') {
  return httpClient.post<AjaxResult>(
    {
      url: Api.GetWareHouseTreeNodes,
      params: {},
    },
    {
      errorMessageMode: mode,
    },
  );
}
