/** 错误消息提示模式 */
export type ErrorMessageMode = 'none' | 'modal' | 'message' | undefined;
export type SuccessMessageMode = ErrorMessageMode;

/** 请求参数 */
export interface RequestOptions {
  /** 将请求参数拼接到url（Splicing request parameters to url） */
  joinParamsToUrl?: boolean;
  /** 格式化请求参数时间（Format request parameter time） */
  formatDate?: boolean;
  /** 是否处理请求结果（Whether to process the request result） */
  isTransformResponse?: boolean;
  /** 是否返回原生响应头 比如：需要获取响应头时使用该属性
   * （Whether to return native response headers For example: use this attribute when you need to get the response headers）
   */
  isReturnNativeResponse?: boolean;
  /** 是否加入url（Whether to join url） */
  joinPrefix?: boolean;
  /** 接口地址，如果保留为空，则使用默认的apiUrl（Interface address, use the default apiUrl if you leave it blank） */
  apiUrl?: string;
  /** 请求拼接路径 */
  urlPrefix?: string;
  /** 错误消息提示类型（Error message prompt type） */
  errorMessageMode?: ErrorMessageMode;
  /** 成功消息提示类型（Success message prompt type） */
  successMessageMode?: SuccessMessageMode;
  /** 是否添加时间戳（Whether to add a timestamp） */
  joinTime?: boolean;
  /** 忽略取消标记（Ignore CancelToken） */
  ignoreCancelToken?: boolean;
  /** 是否在头中发送令牌（Whether to send token in header） */
  withToken?: boolean;
  /** 请求重试机制 */
  retryRequest?: RetryRequest;
}

/** 请求重试机制 */
export interface RetryRequest {
  /** 开启重试机制 */
  isOpenRetry: boolean;
  /** 重试次数 */
  count: number;
  /** 等待时间（毫秒） */
  waitTime: number;
}

/**  返回结果 */
export interface Result<T = any> {
  /**  结果类型 */
  Type: number;
  /**  消息内容 */
  Content: string;
  /**  返回数据 */
  Data: T;
}

/** 多部分/表单数据：上载文件（multipart/form-data: upload file） */
export interface UploadFileParams {
  /** 其他参数（Other parameters） */
  data?: Recordable;
  /** 文件参数接口字段名称（File parameter interface field name） */
  name?: string;
  /** 文件（file name） */
  file: File | Blob;
  /** 文件名（file name） */
  filename?: string;
  [key: string]: any;
}
