import { MenuTypeEnum, MenuModeEnum, TriggerEnum, MixSidebarTriggerEnum } from '/@/enums/menuEnum';
import {
  ContentEnum,
  PermissionModeEnum,
  ThemeEnum,
  RouterTransitionEnum,
  SettingButtonPositionEnum,
  SessionTimeoutProcessingEnum,
} from '/@/enums/appEnum';

import { CacheTypeEnum } from '/@/enums/cacheEnum';

/** 本地化语言类型
 * ar_AE：阿拉伯语 Arabic
 * az_AZ：阿塞拜疆语 Azerbaijani
 * bg_BG：保加利亚语 Bulgarian
 * bn_BD：孟加拉语 Bengali
 * ca_CA：加泰罗尼亚语 Catalan
 * cs_CZ：捷克语 Czech
 * cy_GB：威尔士语 Welsh
 * da_DK：丹麦语（丹麦）Danish (Denmark)
 * de_DE：德语 German
 * dv_DV：迪维希语 Dhivehi
 * el_GR：希腊语 Greek
 * en_US：英语（美国）English (United States)
 * en_GB：英语（英国）English (United Kingdom)
 * es_ES：西班牙语 Spanish
 * et_EE：爱沙尼亚语 Estonian
 * eu_ES：巴斯克语 Basque
 * fa_IR：波斯语 Persian
 * fi_FI：芬兰语（芬兰）Finnish (Finland)
 * fr_FR：法语 French
 * ga_IE：爱尔兰语 Irish
 * gl_ES：加利西亚语 Galician
 * he_IL：希伯来语（以色列）Hebrew (Israel)
 * hi_IN：印地语 Hindi
 * hr_HR：克罗地亚语 Croatian
 * hu_HU：匈牙利语 Hungarian
 * hy_AM：亚美尼亚语 Armenian
 * id_ID：印度尼西亚语 Indonesian
 * is_IS：冰岛语 Icelandic
 * it_IT：意大利语 Italian
 * ja_JP：日语 Japanese
 * kab_DZ：卡拜尔语 Kabyle
 * kk_KZ：哈萨克语 Kazakh
 * ko_KR：朝鲜语（南韩）Korean
 * ckb_IR：库尔德语 Kurdish
 * lt_LT：立陶宛语 Lithuanian
 * lv_LV：拉脱维亚语 Latvian
 * nb_NB：挪威博克马尔语 Norwegian Bokmal
 * nb_NO：挪威语（挪威）Norwegian (Norway)
 * ne_NP：尼泊尔语 Nepali
 * nl_NL：荷兰语（荷兰）Dutch (Netherlands)
 * nl_BE：荷兰语（比利时）Dutch (Belgium)
 * oc_OC：奥克语 Occitan
 * pl_PL：波兰语 Polish
 * pt_PT：葡萄牙语 Portuguese
 * pt_BR：葡萄牙语（巴西）Portuguese (Brazil)
 * ro_RO：罗马尼亚语 Romanian
 * ru_RU：俄语 Russian
 * sk_SK：斯洛伐克语 Slovak
 * sl_SL：斯洛文尼亚语 Slovenian
 * sq_AL：阿尔巴尼亚语 Albanian
 * sr_cyrl_RS：塞尔维亚语（西里尔文） Serbian
 * sv_SE：瑞典语 Swedish
 * ta_IN：泰米尔语 Tamil
 * tg_TJ：塔吉克语 Tajik
 * th_TH：泰语 Thai
 * tr_TR：土耳其语 Turkish
 * ug_CN：维吾尔语 Uyghur
 * uk_UK：乌克兰语 Ukrainian
 * vi_VN：越南语 Vietnamese
 * zh_CN：简体中文 Chinese
 * zh_TW：繁体中文（台湾）Traditional Chinese (Tai Wan)
 */
export type LocaleType =
  | 'ar_AE'
  | 'az_AZ'
  | 'bg_BG'
  | 'bn_BD'
  | 'ca_CA'
  | 'cs_CZ'
  | 'cy_GB'
  | 'da_DK'
  | 'de_DE'
  | 'dv_DV'
  | 'el_GR'
  | 'en_US'
  | 'en_GB'
  | 'es_ES'
  | 'et_EE'
  | 'eu_ES'
  | 'fa_IR'
  | 'fi_FI'
  | 'fr_FR'
  | 'ga_IE'
  | 'gl_ES'
  | 'he_IL'
  | 'hi_IN'
  | 'hr_HR'
  | 'hu_HU'
  | 'hy_AM'
  | 'id_ID'
  | 'is_IS'
  | 'it_IT'
  | 'ja_JP'
  | 'kab_DZ'
  | 'kk_KZ'
  | 'ko_KR'
  | 'ckb_IR'
  | 'lt_LT'
  | 'lv_LV'
  | 'nb_NB'
  | 'nb_NO'
  | 'ne_NP'
  | 'nl_NL'
  | 'nl_BE'
  | 'oc_OC'
  | 'pl_PL'
  | 'pt_PT'
  | 'pt_BR'
  | 'ro_RO'
  | 'ru_RU'
  | 'sk_SK'
  | 'sl_SL'
  | 'sq_AL'
  | 'sr_cyrl_RS'
  | 'sv_SE'
  | 'ta_IN'
  | 'tg_TJ'
  | 'th_TH'
  | 'tr_TR'
  | 'ug_CN'
  | 'uk_UK'
  | 'vi_VN'
  | 'zh_CN'
  | 'zh_TW';

/** 菜单配置（Menu configuration） */
export interface MenuSetting {
  /** 背景色（sidebar menu bg color） */
  bgColor: string;
  /** 是否固定左侧菜单（Whether to fix the left menu） */
  fixed: boolean;
  /** 菜单折叠（Menu collapse） */
  collapsed: boolean;
  /** 响应性布局时隐藏sider（When sider hide because of the responsive layout） */
  siderHidden: boolean;
  /** 是否可拖拽（Whether it can be dragged）
   * 注：仅限于打开左侧菜单，鼠标在菜单右侧有一个拖动条
   * （Only limited to the opening of the left menu, the mouse has a drag bar on the right side of the menu）
   */
  canDrag: boolean;
  /** 是否显示（Whether to show no dom） */
  show: boolean;
  /** 是否隐藏（Whether to show dom） */
  hidden: boolean;
  /** 拆分菜单（Split menu） */
  split: boolean;
  /** 菜单宽度（Menu width） */
  menuWidth: number;
  /** 菜单模式（Menu mode） */
  mode: MenuModeEnum;
  /** 菜单类型（Menu type） */
  type: MenuTypeEnum;
  /** 菜单主题（Menu theme） */
  theme: ThemeEnum;
  /** 顶部菜单布局（Top menu layout） */
  topMenuAlign: 'start' | 'center' | 'end';
  /** 折叠触发位置（Fold trigger position） */
  trigger: TriggerEnum;
  /** 手风琴模式，只展示一个菜单（Turn on accordion mode, only show a menu） */
  accordion: boolean;
  /** 在路由切换的时候关闭左侧混合菜单展开菜单（Switch page to close menu） */
  closeMixSidebarOnChange: boolean;
  /** 折叠菜单时候是否显示菜单名（Whether to display the menu name when folding the menu） */
  collapsedShowTitle: boolean;
  /** 左侧混合菜单模块切换触发方式（Module opening method ‘click’ |'hover'） */
  mixSideTrigger: MixSidebarTriggerEnum;
  /** 是否固定左侧混合菜单（Fixed expanded menu） */
  mixSideFixed: boolean;
}

/** 多标签配置（Multi-label settings） */
export interface MultiTabsSetting {
  /** 缓存 */
  cache: false;
  /** 开启（Turn on） */
  show: boolean;
  /** 开启快速操作（Turn on quick actions） */
  showQuick: boolean;
  /** 是否可以拖拽（Is it possible to drag and drop sorting tabs） */
  canDrag: boolean;
  /** 是否显示刷新按钮（Whether to show the refresh button） */
  showRedo: boolean;
  /** 是否显示折叠按钮（Whether to show the collapse button） */
  showFold: boolean;
}

/** 头部配置（Header configuration） */
export interface HeaderSetting {
  /** 背景色（header bg color） */
  bgColor: string;
  /** 固定头部（Fixed at the top） */
  fixed: boolean;
  /** 是否显示顶部（Whether to show top） */
  show: boolean;
  /** 主题（theme） */
  theme: ThemeEnum;
  /** 显示全屏按钮（Whether to show the full screen button） */
  showFullScreen: boolean;
  /** 开启锁屏功能（Whether to enable the lock screen function） */
  useLockPage: boolean;
  /** 显示文档按钮（Whether to show the document button） */
  showDoc: boolean;
  /** 显示消息中心按钮（Whether to show the notification button） */
  showNotice: boolean;
  /** 显示菜单搜索按钮（Whether to display the menu search） */
  showSearch: boolean;
}

/** 本地化语言设置 */
export interface LocaleSetting {
  /** 是否显示语言选择器 */
  showPicker: boolean;
  /** 当前语言（Current language） */
  locale: LocaleType;
  /** 默认语言（default language） */
  fallback: LocaleType;
  /** 允许的语言（available Locales） */
  availableLocales: LocaleType[];
}

/** 过渡动画配置（Transition Setting） */
export interface TransitionSetting {
  /** 是否开启切换动画（Whether to open the page switching animation）
   * 注：禁用状态也将禁用pageLoadinng（The disabled state will also disable pageLoadinng）
   */
  enable: boolean;
  /** 路由基本切换动画（Route basic switching animation） */
  basicTransition: RouterTransitionEnum;
  /** 是否打开页面切换loading（Whether to open page switching loading）
   * 注：仅当enable=true时打开（Only open when enable=true）
   */
  openPageLoading: boolean;
  /** 是否打开页面切换顶部进度条（Whether to open the top progress bar） */
  openNProgress: boolean;
}

/** 定义项目配置接口 */
export interface ProjectConfig {
  /** 权限相关信息的存储位置（Storage location of permission related information） */
  permissionCacheType: CacheTypeEnum;
  /** 是否显示配置按钮（Whether to show the configuration button） */
  showSettingButton: boolean;
  /** 是否显示主题切换按钮（Whether to show the theme switch button） */
  showDarkModeToggle: boolean;
  /** 配置按钮的显示位置（Configure where the button is displayed）
   * SettingButtonPositionEnum.AUTO: 自动选择
   * SettingButtonPositionEnum.HEADER:位于头部
   * SettingButtonPositionEnum.FIXED 固定在右侧
   */
  settingButtonPosition: SettingButtonPositionEnum;
  // 会话超时处理（Session timeout processing）
  sessionTimeoutProcessing: SessionTimeoutProcessingEnum;
  /** 权限模式（Permission mode） */
  permissionMode: PermissionModeEnum;
  /** 网站灰色模式，为可能的哀悼日开放（Website gray mode, open for possible mourning dates） */
  grayMode: boolean;
  /** 是否开启弱色模式（Whether to turn on the color weak mode） */
  colorWeak: boolean;
  /** 主题颜色（Theme color） */
  themeColor: string;

  /** 是否取消菜单,顶部,多标签页显示, 用于可能内嵌在别的系统内
   * （Whether to cancel the menu, the top, the multi-tab page display, for possible embedded in other systems）
   */
  fullContent: boolean;
  /** 内容宽度（content width） */
  contentMode: ContentEnum;
  /** 是否显示Logo（Whether to display the logo） */
  showLogo: boolean;
  /** 是否显示全局页脚（Whether to show the global footer） */
  showFooter: boolean;
  /** 头部配置（Header configuration） */
  headerSetting: HeaderSetting;
  /** 菜单配置（Menu configuration） */
  menuSetting: MenuSetting;
  // Multi-tab settings
  /** 多标签配置（Multi-label settings） */
  multiTabsSetting: MultiTabsSetting;
  /** 过渡动画配置（Transition Setting） */
  transitionSetting: TransitionSetting;
  /** 是否开启KeepAlive缓存，注：开发时候最好关闭,不然每次都需要清除缓存
   * （Whether to enable KeepAlive cache is best to close during development, otherwise the cache needs to be cleared every time）
   */
  openKeepAlive: boolean;
  /** 自动锁屏时间，为0不锁屏。 单位分钟 默认1个小时
   * （Automatic screen lock time, 0 does not lock the screen. Unit minute default 0）
   */
  lockTime: number;
  /** 显示面包屑（Whether to show breadcrumbs） */
  showBreadCrumb: boolean;
  /** 显示面包屑图标（Whether to show the breadcrumb icon） */
  showBreadCrumbIcon: boolean;
  /** 使用错误处理程序插件（Use error-handler-plugin） */
  useErrorHandle: boolean;
  /** 是否开启回到顶部（Whether to open back to top） */
  useOpenBackTop: boolean;
  /** 是否可以嵌入iframe页面（Is it possible to embed iframe pages） */
  canEmbedIFramePage: boolean;
  /** 切换界面的时候是否删除未关闭的message及notify（Whether to delete unclosed messages and notify when switching the interface） */
  closeMessageOnSwitch: boolean;
  /** 切换界面的时候是否取消已经发送但是未响应的http请求。如果开启,想对单独接口覆盖。可以在单独接口设置
   * （Whether to cancel the http request that has been sent but not responded when switching the interface.
   * If it is enabled, I want to overwrite a single interface. Can be set in a separate interface）
   */
  removeAllHttpPending: boolean;
}

/** 全局配置 */
export interface GlobConfig {
  /** 网站标题（Site title） */
  title: string;
  /** 服务接口url前缀（Service interface url prefix） */
  urlPrefix?: string;
  /** 服务接口url（Service interface url） */
  apiUrl?: string;
  /** 第三方登录接口地址 */
  signinUrl?: string;
  /** SignalR接口地址 */
  signalrUrl?: string;
  /** 映射到静态资源的相对请求接口地址，用于直接向后端请求静态资源链接 */
  filesUrl?: string;
  /** 文件上传接口地址（Upload url） */
  uploadUrl?: string;
  /** SignalR接口地址前缀 */
  signalrPrefix?: string;
  /** 映射到静态资源的相对请求接口地址前缀 */
  filesPrefix?: string;
}

/** 全局环境配置 */
export interface GlobEnvConfig {
  /** 网站标题（Site title） */
  VITE_GLOB_APP_TITLE: string;
  /** 服务接口url前缀（Service interface url prefix） */
  VITE_GLOB_API_URL_PREFIX?: string;
  /** 服务接口url（Service interface url） */
  VITE_GLOB_API_URL?: string;
  /** 第三方登录接口地址 */
  VITE_GLOB_SIGNIN_URL?: string;
  /** SignalR接口地址 */
  VITE_GLOB_SIGNALR_URL?: string;
  /** 映射到静态资源的相对请求接口地址，用于直接向后端请求静态资源链接 */
  VITE_GLOB_FILES_URL?: string;
  /** 文件上传接口地址（Upload url） */
  VITE_GLOB_UPLOAD_URL?: string;
  /** SignalR接口地址前缀 */
  VITE_GLOB_SIGNALR_URL_PREFIX?: string;
  /** 映射到静态资源的相对请求接口地址前缀 */
  VITE_GLOB_FILES_URL_PREFIX?: string;
}
