import type {
  ComponentRenderProxy,
  VNode,
  VNodeChild,
  ComponentPublicInstance,
  FunctionalComponent,
  PropType as VuePropType,
} from 'vue';

/** 全局 */
declare global {
  /** 应用程序信息 */
  const __APP_INFO__: {
    /** 包 */
    pkg: {
      /** 名称 */
      name: string;
      /** 版本 */
      version: string;
      /** 依赖项 */
      dependencies: Recordable<string>;
      /** 开发人员依赖项 */
      devDependencies: Recordable<string>;
    };
    /** 最后构建时间 */
    lastBuildTime: string;
  };

  // /**
  //  * 包含DOM文档的窗口；document属性指向该窗口中加载的DOM文档。
  //  * （A window containing a DOM document; the document property points to the DOM document loaded in that window.）
  //  */
  // declare interface Window {
  //   /** 全局应用程序实例（Global vue app instance） */
  //   __APP__: App<Element>;
  // }

  /** 属性类型 */
  // vue
  declare type PropType<T> = VuePropType<T>;
  declare type VueNode = VNodeChild | JSX.Element;

  /** 可写的 */
  export type Writable<T> = {
    -readonly [P in keyof T]: T[P];
  };

  /** 可为空的 */
  declare type Nullable<T> = T | null;
  /** 不可空的 */
  declare type NonNullable<T> = T extends null | undefined ? never : T;
  /** 可记录的 */
  declare type Recordable<T = any> = Record<string, T>;
  /** 只读可记录 */
  declare type ReadonlyRecordable<T = any> = {
    readonly [key: string]: T;
  };
  /** 可转位的 */
  declare type Indexable<T = any> = {
    [key: string]: T;
  };
  /** 深部局部 */
  declare type DeepPartial<T> = {
    [P in keyof T]?: DeepPartial<T[P]>;
  };
  /** 超时处理器 */
  declare type TimeoutHandle = ReturnType<typeof setTimeout>;
  /** 间隔处理器 */
  declare type IntervalHandle = ReturnType<typeof setInterval>;

  /** 更改事件 */
  declare interface ChangeEvent extends Event {
    target: HTMLInputElement;
  }

  /** 车轮事件 */
  declare interface WheelEvent {
    path?: EventTarget[];
  }
  /** 导入元环境 */
  interface ImportMetaEnv extends ViteEnv {
    __: unknown;
  }

  /** Vite环境 */
  declare interface ViteEnv {
    /** 是否开启mock（本地模拟数据）。 Whether to open mock */
    VITE_USE_MOCK: boolean;
    /** 资源公共路径。 public path */
    VITE_PUBLIC_PATH: string;
    /** 标题。 spa-title */
    VITE_GLOB_APP_TITLE: string;
    /** 是否删除Console.log。 Delete console */
    VITE_DROP_CONSOLE: boolean;
    /**
     * 打包是否输出gz｜br文件。 Whether to enable gzip or brotli compression
     * 可选: gzip | brotli | none。 Optional: gzip | brotli | none
     * 也可以有多个, 例如 ‘gzip’|'brotli',这样会同时生成 .gz和.br文件。 If you need multiple forms, you can use `,` to separate
     */
    VITE_BUILD_COMPRESS: 'gzip' | 'brotli' | 'none';
  }

  declare function parseInt(s: string | number, radix?: number): number;

  declare function parseFloat(string: string | number): number;

  namespace JSX {
    // tslint:disable no-empty-interface
    type Element = VNode;
    // tslint:disable no-empty-interface
    type ElementClass = ComponentRenderProxy;
    interface ElementAttributesProperty {
      $props: any;
    }
    interface IntrinsicElements {
      [elem: string]: any;
    }
    interface IntrinsicAttributes {
      [elem: string]: any;
    }
  }
}

declare module 'vue' {
  export type JSXComponent<Props = any> =
    | { new (): ComponentPublicInstance<Props> }
    | FunctionalComponent<Props>;
}
