export {};

declare module 'vue-router' {
  /** 路由单元 */
  interface RouteMeta extends Record<string | number | symbol, unknown> {
    /** 排序。越大排名越后面 */
    orderNo?: number;
    /** 标题（title） */
    title: string;
    /** 动态路由器级别（dynamic router level.） */
    dynamicLevel?: number;
    /** 动态路由器真实路由路径（用于性能）。dynamic router real route path (For performance). */
    realPath?: string;
    /** 是否忽略权限（Whether to ignore permissions） */
    ignoreAuth?: boolean;
    /** 角色信息（role info） */
    roles?: string[];
    /**
     * 是否忽略KeepAlive缓存（Whether not to cache）
     * 注意：keep-alive 生效的前提是：需要将路由的 name 属性及对应的页面的 name 设置成一样。因为：include - 字符串或正则表达式，只有名称匹配的组件会被缓存
     */
    ignoreKeepAlive?: boolean;
    /** 固定在标签上（Is it fixed on tab） */
    affix?: boolean;
    /** 选项卡上的图标（icon on tab） */
    icon?: string;
    /** 框架源 */
    frameSrc?: string;
    /** 当前页面转换（current page transition） */
    transitionName?: string;
    /** 路由是否已动态添加（Whether the route has been dynamically added） */
    hideBreadcrumb?: boolean;
    /** 隐藏子菜单（Hide submenu） */
    hideChildrenInMenu?: boolean;
    /** 承载参数（Carrying parameters） */
    carryParam?: boolean;
    /** 内部用于标记单层菜单（Used internally to mark single-level menus） */
    single?: boolean;
    /** 当前活动菜单（Currently active menu） */
    currentActiveMenu?: string;
    /** 从不在选项卡中显示（Never show in tab） */
    hideTab?: boolean;
    /** 从不在菜单中显示（Never show in menu） */
    hideMenu?: boolean;
    /** 是否链接 */
    isLink?: boolean;
    /** 仅为菜单生成（only build for Menu） */
    ignoreRoute?: boolean;
    /** 隐藏子路径（Hide path for children） */
    hidePathForChildren?: boolean;
  }
}
